********************************************************************************************
************************* IFWE Chigign Tobiya TVET Data Preparation ****************************

* Authors: Sreelakshmi Papineni and Emilia Cucagna, World Bank Africa Gender Innovation Lab
* Created on - November 09, 2022
* Project- IFWE Chigign Tobiya
* Purpose- This do file prepares and cleans the TVET database

********************************************************************************************
********************************************************************************************

******************************************************************
*TVET RESPONDENT

******************************************************************
clear all
use "$usingdata\Chigign_Tobiya_Tvet_study_17Jan2022.dta"


local today : di %tdDNCY daily("$S_DATE", "DMY")



rename consent consent_survey 
foreach var of varlist  TVET_RENEW_FU_1_2     TVET_RENEW_FU_2_2  {
gen `var'_yesno = 2-`var' if consent_survey==1
}



**********Demographics


***RESPONDENT CHARACTERISTICS***
gen tertiary_educ_tvet = 1 if TVET_RENEW_BL_1_15>=20 & TVET_RENEW_BL_1_15!=.
recode tertiary_educ_tvet (.=0) if TVET_RENEW_BL_1_15!=.
label variable tertiary_educ_tvet "Respondent has tertiary education"

gen age_resp_tvet = TVET_RENEW_BL_1_9
label variable age_resp_tvet "Respondent age"

gen married_resp_tvet = 1 if TVET_RENEW_BL_1_11==2
recode married_resp_tvet (.=0) if TVET_RENEW_BL_1_11!=. 
label variable married_resp_tvet "Respondent is married"

**Any business experience
gen any_business_experience = 1 if TVET_RENEW_BL_1_17==1 | TVET_RENEW_BL_1_17==2
recode any_business_experience (.= 0) if TVET_RENEW_BL_1_17==3

**Work for pay in last month
gen paid_work = 1 if TVET_RENEW_BL_1_19==1
recode paid_work (.= 0) if TVET_RENEW_BL_1_19==2
label variable paid_work "Respondent worked in the last month"
label define paid_label 0 "Respondent did not work in the last month" 1 "Respondent worked in the last month"
label values  paid_work paid_label

***Unconditional earnings last month
gen earnings_unc = TVET_RENEW_BL_1_20
recode earnings_unc (.=0) if TVET_RENEW_BL_1_19==2 

gen earnings_cond = TVET_RENEW_BL_1_20

***Household income contributor 
gen no_contribution_hhinc = 1 if  TVET_RENEW_BL_1_21 ==5
recode no_contribution_hhinc (.= 0) if  TVET_RENEW_BL_1_21!=.

gen main_inc_earner = 1 if TVET_RENEW_BL_1_21==1 | TVET_RENEW_BL_1_21==2
recode main_inc_earner (.=0) if TVET_RENEW_BL_1_21!=.

***Credit 
gen ever_took_loan = 1 if TVET_RENEW_BL_1_29==1
recode ever_took_loan (.=0) if TVET_RENEW_BL_1_29==2


gen female=( TVET_RENEW_BL_1_8 ==1)
label variable female "Respondent is female"


forvalue i=1/6{
	gen head_`i'=0 if TVET_RENEW_BL_1_13!=.
	replace head_`i'=1 if TVET_RENEW_BL_1_13==`i'
}

label variable head_1 "Head is self"
label variable head_2 "Head is Spouse"
label variable head_3 "Head is Mother"
label variable head_4 "Head is Father"
label variable head_5 "Head is other female"
label variable head_6 "Head is other male"

gen head=TVET_RENEW_BL_1_13
label variable head "Head of the household"


**** Aspirations
* Respondent aspire to be a business ownwer
gen aspiring_business_owner = 1 if TVET_RENEW_BL_1_26==1
recode aspiring_business_owner (.=0) if  TVET_RENEW_BL_1_26!=.
label variable  aspiring_business_owner "Respondent aspires to be a business owner when graduate"
label define asp_label 0 "Respondent does not aspire to be a business" 1"Respondent aspires to be a business" 
label values aspiring_business_owner asp_label

* Respondent aspire to be a wage employee
gen aspiring_wage_employee = 1 if TVET_RENEW_BL_1_26==3 | TVET_RENEW_BL_1_26==4
recode aspiring_wage_employee (.=0) if  TVET_RENEW_BL_1_26!=.
label variable  aspiring_wage_employee "Respondent aspire to be a wage employee when graduate"


* Respondent aspire to be other
gen aspiring_other= 1 if TVET_RENEW_BL_1_26==2 | TVET_RENEW_BL_1_26==5 | TVET_RENEW_BL_1_26==6 | TVET_RENEW_BL_1_26==7 | TVET_RENEW_BL_1_26==8
recode aspiring_other (.=0) if  TVET_RENEW_BL_1_26!=.
label variable aspiring_other  "Respondent aspire to be other type of work when graduate"



forvalue i=1/7{
	gen aspriring_`i'=0
	replace aspriring_`i'=1 if TVET_RENEW_BL_1_26==`i'
}


***** Pitch type
gen bad_pitch = 1 if videoclip == 7 | videoclip == 8
recode bad_pitch (.=0) if videoclip!=.

gen male_pitch = 1 if videoclip == 4 | videoclip == 5 | videoclip == 6 | videoclip == 7
recode male_pitch (.=0) if videoclip!=.

gen TVET_RENEW_FU_2_5_quality = 5-TVET_RENEW_FU_2_5
gen TVET_RENEW_FU_2_6_success = 5-TVET_RENEW_FU_2_6
gen TVET_RENEW_FU_2_7_risky = 5-TVET_RENEW_FU_2_7
gen TVET_RENEW_FU_2_3_cond = TVET_RENEW_FU_2_3 if TVET_RENEW_FU_2_2_yesno==1


*****Explicit Attitudes and Norms
**TVET sample
des TVET_RENEW_BL_1_22 TVET_RENEW_BL_1_23 TVET_RENEW_BL_1_24 TVET_RENEW_BL_1_25 

**Gender bias (prefer men)
**On the whole, men make better business executives than women do - agree?
gen gen_att_agree = 1 if TVET_RENEW_BL_1_22==4 | TVET_RENEW_BL_1_22==5
recode gen_att_agree (.= 0) if TVET_RENEW_BL_1_22!=.
label variable gen_att_agree "Men make better business executives than women do: Agree/SA" 
label values gen_att_agree att_label2



gen gen_att_strongagree = 1 if TVET_RENEW_BL_1_22==5
recode gen_att_strongagree (.= 0) if TVET_RENEW_BL_1_22!=.
label variable gen_att_strongagree "Men make better business executives than women do: Stronly Agree" 
label values gen_att_strongagree att_label2


gen gen_att_strongdis=1 if TVET_RENEW_BL_1_22==1
recode gen_att_strongdis (.= 0) if TVET_RENEW_BL_1_22!=.
lab var gen_att_strongdis "Men make better business executives than women do: SD"
label values gen_att_strongdis att_label3



gen gen_att_agree_neither=gen_att_agree
replace gen_att_agree_neither=1 if TVET_RENEW_BL_1_22==3
lab var gen_att_agree_neither "Men make better business executives than women do: Strongly agree/Agree/Neither" 
label define att_label5 0"Strongly disagree/Disagree" 1 "Strongly agree/Agree/Neither agree nor disagree"
label values gen_att_agree_neither att_label5





***Women should not enter occupations that are dominated by men

*SA
gen gen_att_strongagree2 = 1 if TVET_RENEW_FU_2_23==5
recode gen_att_strongagree2 (.= 0) if TVET_RENEW_FU_2_23!=.
label variable gen_att_strongagree2 "Women should not enter occupations that are dominated by men: Stronly Agree" 
label define att_label1 0"Strongly disagree/disagree/Neither/Agree" 1 "Strongly agree"
label values gen_att_strongagree2 att_label1


*A
gen gen_att_agree2 = 1 if TVET_RENEW_FU_2_23==4 | TVET_RENEW_FU_2_23==5
recode gen_att_agree2 (.= 0) if TVET_RENEW_FU_2_23!=.
label variable gen_att_agree2 "Women should not enter occupations that are dominated by men: Agree" 
label define att_label2 0"Strongly disagree/disagree/Neither agree nor disagree" 1 "Strongly agree/Agree"
label values gen_att_agree2 att_label2


*SD
gen gen_att_strdisagree2=1 if TVET_RENEW_FU_2_23==1 
recode gen_att_strdisagree2 (.= 0) if TVET_RENEW_FU_2_23!=.
lab var gen_att_strdisagree2 "Women should not enter occupation that are male dominated: SD"
label define att_label3 0"Disagree/Neither/Agree/Stronly agree" 1 "Strongly disagree"
label values gen_att_strdisagree2 att_label3



*D
gen gen_att_disagree2=1 if (TVET_RENEW_FU_2_23==1  | TVET_RENEW_FU_2_23==2)
recode gen_att_disagree2 (.= 0) if TVET_RENEW_FU_2_23!=.
lab var gen_att_disagree2 "Women should not enter occupation that are male dominated: Disagree"
label define att_label4 0"Strongly disagree/Neither/Agree/Stronly agree" 1 "Disagree"
label values gen_att_disagree2 att_label4


*COMBINED
gen explicit_sdisagree=0 if gen_att_strdisagree2!=. & gen_att_strongdis!=.
replace explicit_sdisagree=1 if gen_att_strdisagree2==1 | gen_att_strongdis==1
lab var explicit_sdisagree "Explicit attidue: SD "



********************************
****Neighbors bias
********************************

*** Out of 10 of your neighbors, how many do you think believe that women should not enter occupations that are dominated by men?
gen s_gen_norm2 = TVET_RENEW_FU_2_24/10
gen gen_norm2 = TVET_RENEW_FU_2_24*10
label variable s_gen_norm2 "Percentage of neighbors who believe women should not enter MDO"
label variable gen_norm2 "Out of 10 of your neighbors-Number of them believe women should not enter MDS"


***Out of 10 of your neighbors - how many believe men make better business execs than women
gen s_gen_norm = TVET_RENEW_BL_1_23/10
gen gen_norm = TVET_RENEW_BL_1_23*10
label variable s_gen_norm "Percentage of neighbors who believe men make better business"
label variable gen_norm "Out of 10 of your neighbors-Number of them believe men make better business"


ge neighbors_dummy=0 if s_gen_norm!=. & s_gen_norm2!=.
replace neighbors_dummy=1 if s_gen_norm>=0.5 & s_gen_norm2>=0.5
lab var neighbors_dummy "Out of 10 of your neighbors-More than 5 believe men make better business and women should not enter MDS"

gen gen_norm_dummy=0 if gen_norm!=.
replace gen_norm_dummy=1 if gen_norm>=50
lab var gen_norm_dummy "Number of neighbors think Men make better business: 5 or more"

gen gen_norm_dummy2=0 if gen_norm2!=.
replace gen_norm_dummy2=1 if gen_norm2>=50
lab var gen_norm_dummy2 "Number of neighbors think Women should not enter MDS: 5 or more"

egen neighbors_bias=rowmean(TVET_RENEW_BL_1_23 TVET_RENEW_FU_2_24)
lab var neighbors_bias "Out of 10 of your neighbors, number with bias"
gen neighbors_bias_perc=neighbors_bias/10
lab var  neighbors_bias_perc "Percentage of bias neighbors"





**Age bias (prefer young)
**On the whole, older men make better business executives than younger men do
gen age_att_disagree = 1 if TVET_RENEW_BL_1_24==1 | TVET_RENEW_BL_1_24==2 | TVET_RENEW_BL_1_24==3
recode age_att_disagree  (.= 0) if TVET_RENEW_BL_1_24!=.
label variable age_att_disagree  "Prefer young- Disagree older men make better business executives than younger"
label define dias_label 0"Agree" 1"Disagree"
label values age_att_disagree dias_label

**AGE BIAS
**On the whole, older men make better business executives than younger men do
gen age_att_agree = 1 if TVET_RENEW_BL_1_24==4 | TVET_RENEW_BL_1_24==5
recode age_att_agree  (.= 0) if TVET_RENEW_BL_1_24!=.
label variable age_att_agree "Older men make better business executives than younger men do"

**EDUCATION BIAS (prefer uni grads)
**On the whole, university graduates make better business executives than high school graduates
gen educ_att_agree = 1 if TVET_RENEW_BL_1_25==4 | TVET_RENEW_BL_1_25==5
recode educ_att_agree (.= 0) if TVET_RENEW_BL_1_25!=.







***Out of 10 of your neighbors - how many believe Women should not enter occupation that are dominated by men?
gen s_gen_occ_seg_norm =  TVET_RENEW_FU_2_24/10
gen gen_occ_seg_norm =  TVET_RENEW_FU_2_24*10



***Autonomous decision-making power starting a business
gen sole_decison_startbus = 1 if TVET_RENEW_BL_1_30 ==1
recode sole_decison_startbus (.= 0) if TVET_RENEW_BL_1_30 !=.
label variable sole_decison_startbus "Dont need to ask permission to start a business"


***Rate business knowledge and skills
clonevar own_busskills =  TVET_RENEW_BL_1_31
clonevar males_busskills =  TVET_RENEW_BL_1_32
clonevar females_busskills =  TVET_RENEW_BL_1_33



***Generalized self-efficacy
des TVET_RENEW_BL_1_34- TVET_RENEW_BL_1_43
	egen 	selfeff = rowtotal(TVET_RENEW_BL_1_34 TVET_RENEW_BL_1_35 TVET_RENEW_BL_1_36 TVET_RENEW_BL_1_37 TVET_RENEW_BL_1_38 TVET_RENEW_BL_1_39 TVET_RENEW_BL_1_40 TVET_RENEW_BL_1_41 TVET_RENEW_BL_1_42 TVET_RENEW_BL_1_43)
	replace selfeff = selfeff/10
	foreach var of varlist TVET_RENEW_BL_1_34 TVET_RENEW_BL_1_35 TVET_RENEW_BL_1_36 TVET_RENEW_BL_1_37 TVET_RENEW_BL_1_38 TVET_RENEW_BL_1_39 TVET_RENEW_BL_1_40 TVET_RENEW_BL_1_41 TVET_RENEW_BL_1_42 TVET_RENEW_BL_1_43 {
	replace selfeff = . if mi(`var')
	}
	lab var selfeff "Generalized self efficacy (1 to 5- lowest to highest, avg 10 items)"

	gen selfeff_std = selfeff/5
	lab var selfeff_std "Generalized self efficacy, standardized (0 to 1- lowest to highest)"

gen high_selfeff_std=0 if selfeff_std!=.
replace high_selfeff_std=1 if selfeff_std!=. &  selfeff_std>=0.85
label variable high_selfeff_std "Self efficacy high"
label define high_selfeff_std_label 0"Self efficacy is low" 1"Self efficacy is high"

	
***Family History
**Decision Maker on Critical Expenditures
gen mother_decision_maker = 1 if TVET_RENEW_FU_2_18==1 | TVET_RENEW_FU_2_18==3
recode mother_decision_maker (.=0) if TVET_RENEW_FU_2_18!=.
label variable mother_decision_maker "Mother is decision Maker on Critical Expenditures" 
label define deci_label 0"Mother is not a decision Maker on Critical Expenditures"  1 "Mother is decision Maker on Critical Expenditures" 
label values mother_decision_maker deci_label

gen mother_decision_maker_only = 1 if TVET_RENEW_FU_2_18==1 
recode mother_decision_maker_only (.=0) if TVET_RENEW_FU_2_18!=.
label variable mother_decision_maker_only "Monther is the only decision Maker on Critical Expenditures" 
	
	
gen father_decision_maker = 1 if TVET_RENEW_FU_2_18==2 | TVET_RENEW_FU_2_18==3
recode father_decision_maker (.=0) if TVET_RENEW_FU_2_18!=.	

gen joint_decision_maker = 1 if TVET_RENEW_FU_2_18==3
recode joint_decision_maker (.=0) if TVET_RENEW_FU_2_18!=.

gen anyfem_decision_maker = 1 if TVET_RENEW_FU_2_18==1  | TVET_RENEW_FU_2_18==5 | TVET_RENEW_FU_2_18==7
recode anyfem_decision_maker (.=0) if TVET_RENEW_FU_2_18!=.
label define decifem_label 0"Any female is not a decision Maker on Critical Expenditures"  1 "Any female is decision Maker on Critical Expenditures" 
label values anyfem_decision_maker decifem_label

gen anyfem_decision_maker_only = 1 if TVET_RENEW_FU_2_18==1 | TVET_RENEW_FU_2_18==3 | TVET_RENEW_FU_2_18==5 | TVET_RENEW_FU_2_18==7
recode anyfem_decision_maker_only (.=0) if TVET_RENEW_FU_2_18!=.
label define anyfem_decision_label 0"Any female is not the only decision Maker on Critical Expenditures"  1 "Any female is the only decision Maker on Critical Expenditures" 
label values anyfem_decision_maker_only anyfem_decision_label

gen anymale_decision_maker = 1 if TVET_RENEW_FU_2_18==2 | TVET_RENEW_FU_2_18==3 | TVET_RENEW_FU_2_18==4 | TVET_RENEW_FU_2_18==6
recode anymale_decision_maker (.=0) if TVET_RENEW_FU_2_18!=.


**Breadwinner Status
gen mother_breadwinner = 1 if TVET_RENEW_FU_2_19==1 | TVET_RENEW_FU_2_19==3
recode mother_breadwinner (.=0) if TVET_RENEW_FU_2_19!=.
	
gen father_breadwinner = 1 if TVET_RENEW_FU_2_19==2 | TVET_RENEW_FU_2_19==3
recode father_breadwinner (.=0) if TVET_RENEW_FU_2_19!=.	

gen joint_breadwinner = 1 if TVET_RENEW_FU_2_19==3
recode joint_breadwinner (.=0) if TVET_RENEW_FU_2_19!=.

gen anyfem_breadwinner = 1 if TVET_RENEW_FU_2_19==1 | TVET_RENEW_FU_2_19==3 | TVET_RENEW_FU_2_19==5 | TVET_RENEW_FU_2_19==7
recode anyfem_breadwinner (.=0) if TVET_RENEW_FU_2_19!=.
	
gen anymale_breadwinner = 1 if TVET_RENEW_FU_2_19==2 | TVET_RENEW_FU_2_19==3 | TVET_RENEW_FU_2_19==4 | TVET_RENEW_FU_2_19==6
recode anymale_breadwinner (.=0) if TVET_RENEW_FU_2_19!=.

***Role Model while growing up
gen any_rolemodel = 1 if TVET_RENEW_FU_2_20==1 | TVET_RENEW_FU_2_20==2
recode any_rolemodel (.= 0) if TVET_RENEW_FU_2_20!=.
label define any_label 0"Respondent does not have a role model" 1 "Respondent has a role model"
label values any_rolemodel any_label


gen male_rolemodel = 1 if TVET_RENEW_FU_2_20==1
recode male_rolemodel (.= 0) if TVET_RENEW_FU_2_20!=.
label define male_rolemodel_label 0"Respondent does not have a male role model" 1 "Respondent has a male role model"
label values male_rolemodel male_rolemodel_label


gen female_rolemodel = 1 if TVET_RENEW_FU_2_20==2
recode female_rolemodel (.= 0) if TVET_RENEW_FU_2_20!=.
label define female_rolemodel_label 0"Respondent does not have a female role model" 1 "Respondent has a female role model"
label values female_rolemodel female_rolemodel_label

***Parent Occupation
gen father_business_ownermgr = 1 if TVET_RENEW_FU_2_21==3
recode father_business_ownermgr (.= 0) if TVET_RENEW_FU_2_21!=.
label define father_label 0"Father is not a business owner" 1 "Father is business owner"
label values father_business_ownermgr father_label

gen mother_business_ownermgr = 1 if TVET_RENEW_FU_2_22==3
recode mother_business_ownermgr (.= 0) if TVET_RENEW_FU_2_22!=.
label define mother_label 0"Mother is not a business owner" 1 "Mother is business owner"
label values mother_business_ownermgr mother_label


gen mother_anywork = 1 if TVET_RENEW_FU_2_22==2 | TVET_RENEW_FU_2_22==3 | TVET_RENEW_FU_2_22==4 | TVET_RENEW_FU_2_22==5
recode mother_anywork (.= 0) if TVET_RENEW_FU_2_22!=.
label define mother_label2 0"Mother did not work" 1 "Mother worked"
label values mother_anywork mother_label2




***Admire a male or female entrepreneur
gen male_admire_entrepreneur = 1 if TVET_RENEW_FU_2_26==1
recode male_admire_entrepreneur (.= 0) if TVET_RENEW_FU_2_25!=""
label define yesno 0"No" 1"Yes"
label values male_admire_entrepreneur yesno

gen female_admire_entrepreneur = 1 if TVET_RENEW_FU_2_26==2
recode female_admire_entrepreneur (.= 0) if TVET_RENEW_FU_2_25!=""
label values female_admire_entrepreneur yesno



gen mother_main_inc_earner=TVET_RENEW_FU_2_19==1
replace mother_main_inc_earner=. if TVET_RENEW_FU_2_19==.
lab var mother_main_inc_earner "Mother was main income earner"


gen father_main_inc_earner=TVET_RENEW_FU_2_19==2
replace father_main_inc_earner=. if TVET_RENEW_FU_2_19==.
lab var father_main_inc_earner "Father was main income earner"


gen mother_owned_bss=TVET_RENEW_FU_2_22==3
replace mother_owned_bss=. if TVET_RENEW_FU_2_22==.
lab var mother_owned_bss "Mother owned business, when you were a child"

gen father_owned_bss=TVET_RENEW_FU_2_21==3
replace father_owned_bss=. if TVET_RENEW_FU_2_21==.
lab var father_owned_bss "Father owned business, when you were a child"

gen sector_services=RENEW_BL_1_27==4
replace sector_services=. if RENEW_BL_1_27==.
label var sector_services  "Industry main business operate is services"


gen diff=TVET_RENEW_BL_1_32-TVET_RENEW_BL_1_33
gen no_difference=0 if diff!=.
replace no_difference=1 if diff==0
lab var no_difference "No difference in rating men and female business knowledge and skills"


gen male_better=0 if TVET_RENEW_BL_1_32!=. & TVET_RENEW_BL_1_33!=.
replace  male_better=1 if diff>0
ta diff male_better
lab var male_better "Males better skills(vs females/no difference)"

*** Compare male better vs female better (excluding no differece)
gen male_better_v2=male_better
replace male_better_v2=. if diff==0
lab var male_better_v2 "Males better skills (vs female)"


gen female_better=0 if TVET_RENEW_BL_1_32!=. & TVET_RENEW_BL_1_33!=.
replace  female_better=1 if diff<0
ta diff female_better
lab var female_better "Females better skills (vs men/no diff)"

*** Compare female better vs male better (excluding no differece)
gen female_better_v2=female_better
replace female_better_v2=. if diff==0
lab var female_better_v2 "Females better skills (vs males)"




***********************************************************************************************************
* Treatment variables
***********************************************************************************************************
**Videos
tab videoclip
/*
Groups	Video 1	                            Video 2	                Video 3
1	Business Script 1 - Female - Good Pitch	Educational - Female	Business Script 3 - Female - Good Pitch
2	Business Script 2 - Female - Good Pitch	Emotional - Female 1	Business Script 1 - Female - Good Pitch
3	Business Script 3 - Female - Good Pitch	Role Model - Female 	Business Script 2 - Female - Good Pitch
4	Business Script 1 - Male - Good Pitch	                        Business Script 3 - Male - Good Pitch
5	Business Script 2 - Male - Good Pitch	Emotional - Male 1	    Business Script 1 - Male - Good Pitch
6	Business Script 3 - Male - Good Pitch	Role Model - Male   	Business Script 2 - Male - Good Pitch
7	Business Script 1 - Male - Bad Pitch	Emotional - Male 3	    Business Script 3 - Male - Bad Pitch
8	Business Script 1 - Female - Bad Pitch	Emotional - Female 3	Business Script 3 - Female - Bad Pitch
*/


/**The treatments are coded 1 for the male business script
[1]	Average outcomes for G1_V1 vs G4_V1 = What is the pure gender bias in a stereotypical female sector?
[2]	Average outcomes for G2_V1 vs G5_V1 = What is the pure gender bias in a gender neutral sector?
[3]	Average outcomes for G3_V1 vs G6_V1 = What is the pure gender bias in a stereotypical male sector?
[4]	What is the gender bias controlling for sector (G1_V1 + G2_V1 + G3_V1) vs (G4_V1 + G5_V1 + G6_V1) and control for sector. 
[5]	Average outcomes for (G1_V1 vs G4_V1) vs (G8_V1 vs G7_V1) = Is the gender bias worse in a poor quality pitch?
[6]	Average outcomes for (G1_V1 vs G4_V1) vs (G3_V1 vs G6_V1) vs (G2_V1 vs G5_V1) = Is the gender bias affected by the traditional gender of the sector of operation?
[7]	Average outcomes for G3_V1 vs G1_V2_V3 = Does providing educational content on women earning more in male-dominated sectors change the attitudes of viewers towards female entrepreneurs?
[8]	Average outcomes for G6_V1 vs G4_V2_V3 = Does providing educational content on women earning more in male-dominated sectors change the attitudes of viewers towards male entrepreneurs?
[9]	Average outcomes for G1_V1 vs G2_V2_V3 = Does providing an emotional connection shift the attitudes of the viewers towards female entrepreneurs?
[10] Average outcomes for G4_V1 vs G5_V2_V3 = Does providing an emotional connection shift the attitudes of the viewers towards male entrepreneurs?
[11] Average outcomes for G2_V1 vs G3_V2_V3 = Can we shift the attitudes of viewers towards female entrepreneurs by resetting the norm of what it means to be a successful entrepreneur by showing a female role model?
[12] Average outcomes for G5_V1 vs G6_V2_V3 = Can we shift the attitudes of viewers towards male entrepreneurs by resetting the norm of what it means to be a successful entrepreneur by showing a male role model?
[13] Average outcomes for G6_V1 vs G7_V2_V3 = Can we compensate for a bad pitch by providing an emotional connection among male entrepreneurs?
[14] Average outcomes for G3_V1 vs G8_V2_V3 = Can we compensate for a bad pitch by providing an emotional connection among female entrepreneurs?

Is there a confounding effect of seeing a second video? The second video is only there for the interventions? If we compare for men that there is no effect then we can say first and second doesn't make a difference. 
*/

gen treatment_good_1 = 1 if videoclip==4
recode treatment_good_1 (.=0) if videoclip==1
label var treatment_good_1 "Cafe Good Pitch  Male (1) vs Female"

gen treatment_good_2 = 1 if videoclip==5
recode treatment_good_2 (.=0) if videoclip==2
label var treatment_good_2 "Textile Good Pitch  Male (1) vs Female"

gen treatment_good_3 = 1 if videoclip==6
recode treatment_good_3 (.=0) if videoclip==3
label var treatment_good_3 "Construction Good Pitch  Male (1) vs Female"

gen treatment_good_all = 1 if videoclip==4 | videoclip==5 | videoclip==6
recode treatment_good_all (.=0) if videoclip==1 | videoclip==2 | videoclip==3
label var treatment_good_all "Good Pitch Male (1) vs Good Pitch Female"

gen treatment_bad_1 = 1 if videoclip==7
recode treatment_bad_1 (.=0) if videoclip==8
label var treatment_bad_1 "Business Script 1 Cafe - Bad Pitch"

gen treatment_goodvsbad_f_1 = 1 if videoclip==1
recode treatment_goodvsbad_f_1 (.=0) if videoclip==8
label var treatment_goodvsbad_f_1 "Business Script 1 Cafe - Female Good (1) vs Bad Pitch"

gen treatment_goodvsbad_m_1 = 1 if videoclip==4
recode treatment_goodvsbad_m_1 (.=0) if videoclip==7
label var treatment_goodvsbad_m_1 "Business Script 1 Cafe - Male Good (1) vs Bad Pitch"

gen sector_video = 1 if videoclip ==4 | videoclip==1
replace sector_video = 2 if videoclip ==5 | videoclip==2
replace sector_video = 3 if videoclip ==6 | videoclip==3
replace sector_video = 1 if videoclip ==7 | videoclip==8

label define sector 1 "Cafe Business (FDS)" 2 "Textile Business (GNS)" 3 "Construction (MDS)" 
label values sector_video sector

gen TVET_RENEW_FU_1_5_quality = 5-TVET_RENEW_FU_1_5
gen TVET_RENEW_FU_1_6_success = 5-TVET_RENEW_FU_1_6
gen TVET_RENEW_FU_1_7_risky = 5-TVET_RENEW_FU_1_7

gen TVET_RENEW_FU_1_3_cond = TVET_RENEW_FU_1_3 if TVET_RENEW_FU_1_2_yesno==1
label variable TVET_RENEW_FU_1_3_cond "3. Cond. How much Birr do you think the tycoons should invest in this"


foreach var of varlist TVET_RENEW_FU_1_3 TVET_RENEW_FU_1_3_cond TVET_RENEW_FU_2_3 {
gen log_`var'=log(`var')
}


foreach var of varlist TVET_RENEW_FU_1_3 TVET_RENEW_FU_1_3_cond TVET_RENEW_FU_2_3 {
gen ihs_`var'=asinh(`var')
}

clonevar tvet_id = respo_id

tostring tvet_id, replace


*gen sector variable sector_bus from  TVET_RENEW_BL_1_28 that's a bit more aggregated
gen sector_bus =. 

replace sector_bus = 1 if TVET_RENEW_BL_1_28 == 1 | TVET_RENEW_BL_1_28==7
replace sector_bus = 2 if TVET_RENEW_BL_1_28==2
replace sector_bus = 3 if TVET_RENEW_BL_1_28==3 | TVET_RENEW_BL_1_28==15 
replace sector_bus = 4 if TVET_RENEW_BL_1_28==4 | TVET_RENEW_BL_1_28==22
replace sector_bus = 5 if TVET_RENEW_BL_1_28==5
replace sector_bus = 6 if TVET_RENEW_BL_1_28==6 | TVET_RENEW_BL_1_28==8
replace sector_bus = 7 if TVET_RENEW_BL_1_28==9
replace sector_bus = 8 if TVET_RENEW_BL_1_28==10
replace sector_bus = 9 if TVET_RENEW_BL_1_28==11
replace sector_bus= 10 if TVET_RENEW_BL_1_28==13 | TVET_RENEW_BL_1_28==14 | TVET_RENEW_BL_1_28==17 | TVET_RENEW_BL_1_28==18 | TVET_RENEW_BL_1_28==19 | TVET_RENEW_BL_1_28==20  | TVET_RENEW_BL_1_28==21
replace sector_bus = 11 if TVET_RENEW_BL_1_28==16
replace sector_bus = 12 if TVET_RENEW_BL_1_28==24 | TVET_RENEW_BL_1_28==26 
replace sector_bus = 13 if TVET_RENEW_BL_1_28==12 
replace sector_bus = 14 if TVET_RENEW_BL_1_28==23 
replace sector_bus = 15 if TVET_RENEW_BL_1_28==25 | TVET_RENEW_BL_1_28==28 | TVET_RENEW_BL_1_28==27
replace sector_bus = 16 if TVET_RENEW_BL_1_28==29 | TVET_RENEW_BL_1_28==31 | TVET_RENEW_BL_1_28==32 | TVET_RENEW_BL_1_28==33
replace sector_bus = 17 if TVET_RENEW_BL_1_28==35 

label define sector_new_1 ///
      1 "Textile Manufacturing" ///
	  2 "Leather Manufacturing" ///	  
	  3 "Food Production" ///
      4 "Machinery/Industrials"     ///
      5 "Wood works" ///
	  6 "Construction" ///
	  7 "Wholesale"  ///
	  8 "Retail"  ///
	  9 "Transport services"  ///
	  10 "Maintenance and Other Services"  ///
	  11 "Business Services"  ///
	  12 "ICT"  ///
  	  13 "Cafes/Restaurants" ///
	  14 "Beauty Salon"  ///	  
	  15 "Cleaning and Decorating Services"  ///
	  16 "Agribusiness"  ///
	  17 "Other"   
label values sector_bus sector_new_1


foreach var of varlist TVET_RENEW_FU_1_1 TVET_RENEW_FU_1_10 TVET_RENEW_FU_1_11 TVET_RENEW_FU_1_12 TVET_RENEW_FU_1_13 TVET_RENEW_FU_1_14 TVET_RENEW_FU_1_15 TVET_RENEW_FU_1_16 TVET_RENEW_FU_2_1  TVET_RENEW_FU_2_10 TVET_RENEW_FU_2_11 TVET_RENEW_FU_2_12 TVET_RENEW_FU_2_13 TVET_RENEW_FU_2_14 TVET_RENEW_FU_2_15 TVET_RENEW_FU_2_16 TVET_RENEW_FU_2_17 {
gen `var'_yesno = 2-`var'
local label : variable label `var'
label variable `var'_yesno  "`label'"
}



sort tvet_id
save "$intermediatedata\Chigign_Tobiya_TVET_Clean_`today'.dta", replace



************************************************************************************************************************************





