********************************************************************************************
********************************************************************************************
************************* IFWE Chigign Tobiya MFI Data preparation****************************

* Authors: Sreelakshmi Papineni and Emilia Cucagna, World Bank Africa Gender Innovation Lab
* Created on - November 09, 2022
* Project- IFWE Chigign Tobiya
* Purpose- This do file prepares and cleans the MFI database
* Updated: June 2025
********************************************************************************************
********************************************************************************************

************************************************************************
* MFI database
************************************************************************

clear all

local today : di %tdDNCY daily("$S_DATE", "DMY")


use "$usingdata\Chigign_Tobiya_mfi_study_17Jan2022.dta"


gen consent_survey = 1 if consent==1
recode consent_survey (.=0)
recode consent_survey (1=0) if MFI_RENEW_BL_1_1=="BeBInCuO"

label var consent_survey "Survey completed"

rename consent_survey consent_survey_mfi

drop if MFI_RENEW_BL_1_10==-999999999



foreach var of varlist MFI_RENEW_FU_1_1 TVET_RENEW_FU_1_2 MFI_RENEW_FU_1_10 MFI_RENEW_FU_1_11 MFI_RENEW_FU_1_12 MFI_RENEW_FU_1_13 MFI_RENEW_FU_1_14 MFI_RENEW_FU_1_15 MFI_RENEW_FU_1_16 MFI_RENEW_FU_2_1 MFI_RENEW_FU_2_2 MFI_RENEW_FU_2_10 MFI_RENEW_FU_2_11 MFI_RENEW_FU_2_12 MFI_RENEW_FU_2_13 MFI_RENEW_FU_2_14 MFI_RENEW_FU_2_15 MFI_RENEW_FU_2_16 MFI_RENEW_FU_2_17 {
gen `var'_yesno = 2-`var' if consent_survey_mfi==1
}


drop if interview__key=="25-42-32-50" & MFI_RENEW_BL_1_1=="MeAInCuO"
drop if interview__key=="06-08-66-40" & MFI_RENEW_BL_1_1=="AbYBeCuO"
drop if interview__key=="38-11-94-16" & MFI_RENEW_BL_1_1=="DeMInCuO"
drop if interview__key=="08-80-36-53" & MFI_RENEW_BL_1_1=="MeKuBeCuO"
drop if interview__key=="68-18-27-68" & MFI_RENEW_BL_1_1=="EpGeBeCuO"


gen treatment = 1 if rand_vid==2
replace treatment = 0 if rand_vid==1



encode strata, gen(d_strata)
encode subcity, gen (d_subcity)

encode MFI_RENEW_BL_1_5, gen (d_branch)

rename TVET_RENEW_FU_1_2_yesno MFI_RENEW_FU_1_2_yesno

gen MFI_RENEW_FU_1_3_cond = MFI_RENEW_FU_1_3 if MFI_RENEW_FU_1_2_yesno==1
gen MFI_RENEW_FU_2_3_cond = MFI_RENEW_FU_2_3 if MFI_RENEW_FU_2_2_yesno==1

label variable  MFI_RENEW_FU_1_3_cond "3.cond How much Birr do you think the tycoons should invest in this business idea?"
label variable MFI_RENEW_FU_2_3_cond "3.cond How much Birr do you think the tycoons should invest in this business idea?"

gen MFI_RENEW_FU_1_5_quality = 5-MFI_RENEW_FU_1_5
gen MFI_RENEW_FU_1_6_success = 5-MFI_RENEW_FU_1_6
gen MFI_RENEW_FU_1_7_risky = 5-MFI_RENEW_FU_1_7
gen MFI_RENEW_FU_2_5_quality = 5-MFI_RENEW_FU_2_5
gen MFI_RENEW_FU_2_6_success = 5-MFI_RENEW_FU_2_6
gen MFI_RENEW_FU_2_7_risky = 5-MFI_RENEW_FU_2_7


clonevar tvet_id = MFI_RENEW_BL_1_1

sort tvet_id


gen tertiary_educ = 1 if MFI_RENEW_BL_1_17>=20 & MFI_RENEW_BL_1_17!=.
recode tertiary_educ (.=0) if MFI_RENEW_BL_1_17!=.

rename tertiary_educ tertiary_educ_mfi
label variable tertiary_educ_mfi "Tertiary education"



recode MFI_RENEW_BL_1_10   (-999999999=.)
gen female_mfi = MFI_RENEW_BL_1_10 
recode female_mfi (2=0)




recode MFI_RENEW_BL_1_13 (-999999999=.)
gen age_resp_mfi =  MFI_RENEW_BL_1_11 if consent_survey_mfi==1

gen married_resp_mfi =  1 if MFI_RENEW_BL_1_13==2 & consent_survey_mfi==1
recode married_resp_mfi (.=0) if MFI_RENEW_BL_1_13!=. & consent_survey_mfi==1

gen self_hhhead_mfi =  1 if MFI_RENEW_BL_1_15==1 & consent_survey_mfi==1

recode self_hhhead_mfi (.=0) if MFI_RENEW_BL_1_15!=. & consent_survey_mfi==1

label variable self_hhhead_mfi "Respondent is head of the household"
gen num_children_mfi =  MFI_RENEW_BL_1_16 if consent_survey_mfi	==1


***MFI Sample
**Decision Maker on Critical Expenditures
gen mother_decision_maker_mfi = 1 if MFI_RENEW_FU_2_18==1 | MFI_RENEW_FU_2_18==3
recode mother_decision_maker_mfi (.=0) if MFI_RENEW_FU_2_18!=. & consent_survey_mfi==1
label variable mother_decision_maker_mfi "Mother decides about money spending priorities in critical"
	
gen father_decision_maker_mfi = 1 if MFI_RENEW_FU_2_18==2 | MFI_RENEW_FU_2_18==3
recode father_decision_maker_mfi (.=0) if MFI_RENEW_FU_2_18!=.	& consent_survey_mfi==1
label variable father_decision_maker_mfi "Father decides about money spending priorities in critical"


gen joint_decision_maker_mfi = 1 if MFI_RENEW_FU_2_18==3
recode joint_decision_maker_mfi (.=0) if MFI_RENEW_FU_2_18!=. & consent_survey_mfi==1
label variable joint_decision_maker_mfi "Mother and father decides about money spending priorities in critical"


gen anyfem_decision_maker_mfi = 1 if MFI_RENEW_FU_2_18==1 | MFI_RENEW_FU_2_18==3 | MFI_RENEW_FU_2_18==5 | MFI_RENEW_FU_2_18==6
recode anyfem_decision_maker_mfi (.=0) if MFI_RENEW_FU_2_18!=. & consent_survey_mfi==1
	label variable anyfem_decision_maker_mfi "Any female decides about money spending priorities in critical"

****Check  MFI_RENEW_FU_2_18 if number 6 is male or female


gen anymale_decision_maker_mfi = 1 if MFI_RENEW_FU_2_18==2 | MFI_RENEW_FU_2_18==3 | MFI_RENEW_FU_2_18==4 | MFI_RENEW_FU_2_18==7
recode anymale_decision_maker_mfi (.=0) if MFI_RENEW_FU_2_18!=. & consent_survey_mfi==1
	label variable anymale_decision_maker_mfi "Any male decides about money spending priorities in critical"

**Breadwinner Status
gen mother_breadwinner_mfi = 1 if MFI_RENEW_FU_2_19==1 | MFI_RENEW_FU_2_19==3
recode mother_breadwinner_mfi (.=0) if MFI_RENEW_FU_2_19!=. & consent_survey_mfi==1
label variable mother_breadwinner_mfi  "Mother was main income earners when growing up"	

gen father_breadwinner_mfi = 1 if MFI_RENEW_FU_2_19==2 | MFI_RENEW_FU_2_19==3
recode father_breadwinner_mfi (.=0) if MFI_RENEW_FU_2_19!=.	 & consent_survey_mfi==1
label variable father_breadwinner_mfi  "Father was main income earners when growing up"	

gen joint_breadwinner_mfi = 1 if MFI_RENEW_FU_2_19==3
recode joint_breadwinner_mfi (.=0) if MFI_RENEW_FU_2_19!=. & consent_survey_mfi==1
label variable joint_breadwinner_mfi  " Both mother and father was main income earners when growing up"	

***Check 
gen anyfem_breadwinner_mfi = 1 if MFI_RENEW_FU_2_19==1 | MFI_RENEW_FU_2_19==3 | MFI_RENEW_FU_2_19==4 
recode anyfem_breadwinner_mfi (.=0) if MFI_RENEW_FU_2_19!=. & consent_survey_mfi==1
	label variable anyfem_breadwinner_mfi  " Any female was main income earners when growing up"	

	
gen anymale_breadwinner_mfi = 1 if MFI_RENEW_FU_2_19==2 | MFI_RENEW_FU_2_19==3 | MFI_RENEW_FU_2_19==7 
recode anymale_breadwinner_mfi (.=0) if MFI_RENEW_FU_2_19!=. & consent_survey_mfi==1
	label variable anymale_breadwinner_mfi  " Any male was main income earners when growing up"	

	
	
***Role Model while growing up
gen any_rolemodel_mfi = 1 if MFI_RENEW_FU_2_20==1 | MFI_RENEW_FU_2_20==2
recode any_rolemodel_mfi (.= 0) if MFI_RENEW_FU_2_20!=.  & consent_survey_mfi==1
label variable any_rolemodel_mfi "Respondent has a role model"


gen male_rolemodel_mfi = 1 if MFI_RENEW_FU_2_20==1
recode male_rolemodel_mfi (.= 0) if MFI_RENEW_FU_2_20!=.  & consent_survey_mfi==1
label variable male_rolemodel_mfi "Respondent has a male role model"



gen female_rolemodel_mfi = 1 if MFI_RENEW_FU_2_20==2
recode female_rolemodel_mfi (.= 0) if MFI_RENEW_FU_2_20!=.  & consent_survey_mfi==1
label variable female_rolemodel_mfi "Respondent has a female role model"


***Parent Occupation
gen father_business_ownermgr_mfi = 1 if MFI_RENEW_FU_2_21==3
recode father_business_ownermgr_mfi (.= 0) if MFI_RENEW_FU_2_21!=.  & consent_survey_mfi==1

label variable father_business_ownermgr_mfi "Father owned or managed a business "

gen mother_business_ownermgr_mfi = 1 if MFI_RENEW_FU_2_22==3
recode mother_business_ownermgr_mfi (.= 0) if MFI_RENEW_FU_2_22!=.  & consent_survey_mfi==1
label variable mother_business_ownermgr_mfi "Mother owned or managed a business "


gen mother_anywork_mfi = 1 if MFI_RENEW_FU_2_22==2 | MFI_RENEW_FU_2_22==3 | MFI_RENEW_FU_2_22==4 | MFI_RENEW_FU_2_22==5
recode mother_anywork_mfi (.= 0) if MFI_RENEW_FU_2_22!=.  & consent_survey_mfi==1
label variable mother_anywork_mfi "Mother did any work "



***Gender Attitudes Women should not enter occupation that are dominated by men?

gen gen_att_occ_seg_agree_mfi = 1 if MFI_RENEW_FU_2_23==4 | MFI_RENEW_FU_2_23==5
recode gen_att_occ_seg_agree_mfi (.= 0) if MFI_RENEW_FU_2_23!=. & consent_survey_mfi==1
label variable gen_att_occ_seg_agree_mfi "Women should not enter occupation that are dominated by men?"

***Out of 10 of your neighbors - how many believe Women should not enter occupation that are dominated by men?
gen s_gen_occ_seg_norm_mfi =  MFI_RENEW_FU_2_24/10 if consent_survey_mfi==1
label variable  s_gen_occ_seg_norm_mfi "how many neighbors believe Women should not enter occupation dominated by men"

gen gen_occ_seg_norm_mfi =  MFI_RENEW_FU_2_24*10  if consent_survey_mfi==1
label variable  gen_occ_seg_norm_mfi "how many neighbors believe Women should not enter occupation dominated by men"


***% of loan applications are from female business owners
gen pct_loan_app_females_mfi = MFI_RENEW_FU_2_25 if consent_survey_mfi==1

gen pct_loan_portfolio_females_mfi = MFI_RENEW_FU_2_26 if consent_survey_mfi==1

***Admire a male or female entrepreneur
gen male_admire_entrepreneur_mfi = 1 if MFI_RENEW_FU_2_28==1
recode male_admire_entrepreneur_mfi (.= 0) if MFI_RENEW_FU_2_27!="" & consent_survey_mfi==1
label variable male_admire_entrepreneur_mfi "Gender of the entrepreneur admired is male"

gen female_admire_entrepreneur_mfi = 1 if MFI_RENEW_FU_2_28==2
recode female_admire_entrepreneur_mfi (.= 0) if MFI_RENEW_FU_2_27!="" & consent_survey_mfi==1
label variable female_admire_entrepreneur_mfi "Gender of the entrepreneur admired is female"

**MFI sample
des MFI_RENEW_BL_1_23 MFI_RENEW_BL_1_24 MFI_RENEW_BL_1_25 MFI_RENEW_BL_1_26

**On the whole, men make better business executives than women do - agree?
gen gen_att_agree_mfi = 1 if MFI_RENEW_BL_1_23==4 | MFI_RENEW_BL_1_23==5
recode gen_att_agree_mfi (.= 0) if MFI_RENEW_BL_1_23!=. & consent_survey_mfi==1
label variable  gen_att_agree_mfi "On the whole, men make better business executives than women do - agree?"

***Out of 10 of your neighbors - how many believe men make better business execs than women
gen s_gen_norm_mfi = MFI_RENEW_BL_1_24/10 if consent_survey_mfi==1
label variable  s_gen_norm_mfi "how many neighbors believe men make better business execs than women"


gen gen_norm_mfi = MFI_RENEW_BL_1_24*10 if consent_survey_mfi==1
label variable  gen_norm_mfi "how many neighbors believe men make better business execs than women"


**Age bias (prefer young)
**On the whole, older men make better business executives than younger men do
gen age_att_disagree_mfi = 1 if MFI_RENEW_BL_1_25==1 | MFI_RENEW_BL_1_25==2 | MFI_RENEW_BL_1_25==3
recode age_att_disagree_mfi (.= 0) if MFI_RENEW_BL_1_25!=. & consent_survey_mfi==1
label variable  age_att_disagree_mfi "On the whole, older men make better business executives than younger men do"

**Age bias 
**On the whole, older men make better business executives than younger men do
gen age_att_agree_mfi  = 1 if MFI_RENEW_BL_1_25==4 | MFI_RENEW_BL_1_25==5
recode age_att_agree_mfi   (.= 0) if MFI_RENEW_BL_1_25!=. & consent_survey_mfi==1
label variable age_att_agree_mfi  "Older men make better business executives than younger men do"



**Education bias (prefer uni grads)
**On the whole, university graduates make better business executives than high school graduates
gen educ_att_agree_mfi = 1 if MFI_RENEW_BL_1_26==4 | MFI_RENEW_BL_1_26==5
recode educ_att_agree_mfi (.= 0) if MFI_RENEW_BL_1_26!=. & consent_survey_mfi==1
label variable  educ_att_agree_mfi "On the whole, university graduates make better business executives than high school graduates"




**Any business experience
gen any_business_experience_mfi = 1 if MFI_RENEW_BL_1_19==1 | MFI_RENEW_BL_1_19==2
recode any_business_experience_mfi (.= 0) if MFI_RENEW_BL_1_19==3 & consent_survey_mfi==1
label variable any_business_experience_mfi "Respondent  managed or owned a business"

des MFI_RENEW_BL_1_36 MFI_RENEW_BL_1_37 MFI_RENEW_BL_1_38 MFI_RENEW_BL_1_39 MFI_RENEW_BL_1_40 MFI_RENEW_BL_1_41 MFI_RENEW_BL_1_42 MFI_RENEW_BL_1_43 MFI_RENEW_BL_1_44 MFI_RENEW_BL_1_45
	egen 	selfeff_mfi = rowtotal(MFI_RENEW_BL_1_36 MFI_RENEW_BL_1_37 MFI_RENEW_BL_1_38 MFI_RENEW_BL_1_39 MFI_RENEW_BL_1_40 MFI_RENEW_BL_1_41 MFI_RENEW_BL_1_42 MFI_RENEW_BL_1_43 MFI_RENEW_BL_1_44 MFI_RENEW_BL_1_45) if consent_survey_mfi==1
	replace selfeff_mfi = selfeff_mfi/10
	foreach var of varlist MFI_RENEW_BL_1_36 MFI_RENEW_BL_1_37 MFI_RENEW_BL_1_38 MFI_RENEW_BL_1_39 MFI_RENEW_BL_1_40 MFI_RENEW_BL_1_41 MFI_RENEW_BL_1_42 MFI_RENEW_BL_1_43 MFI_RENEW_BL_1_44 MFI_RENEW_BL_1_45 {
	replace selfeff_mfi = . if mi(`var')
	}
	lab var selfeff_mfi "Generalized self efficacy (1 to 5- lowest to highest, avg 10 items) MFI"

	gen selfeff_std_mfi = selfeff_mfi/5
	lab var selfeff_std_mfi "Generalized self efficacy, standardized (0 to 1- lowest to highest) MFI"

***Which loans do they support?	
clonevar group_loan_mfi = MFI_RENEW_BL_1_32__1 if consent_survey_mfi==1
clonevar msme_loan_mfi = MFI_RENEW_BL_1_32__2 if consent_survey_mfi==1
clonevar wedp_loan_mfi = MFI_RENEW_BL_1_32__3 if consent_survey_mfi==1
clonevar smefp_loan_mfi = MFI_RENEW_BL_1_32__4 if consent_survey_mfi==1
clonevar youthenterprise_loan_mfi = MFI_RENEW_BL_1_32__5 if consent_survey_mfi==1
clonevar business_loan_mfi = MFI_RENEW_BL_1_32__6 if consent_survey_mfi==1
clonevar personal_loan_mfi = MFI_RENEW_BL_1_32__7 if consent_survey_mfi==1
clonevar consumer_loan_mfi = MFI_RENEW_BL_1_32__8 if consent_survey_mfi==1
clonevar coopunion_loan_mfi = MFI_RENEW_BL_1_32__9 if consent_survey_mfi==1
clonevar other_loan_mfi = MFI_RENEW_BL_1_32__10 if consent_survey_mfi==1

**Number of loan application decisions per month
gen num_loan_app_decision_mfi =  MFI_RENEW_BL_1_33 if consent_survey_mfi==1

**Percentage of time spent engaging with customers
gen pct_time_with_customers_mfi =  MFI_RENEW_BL_1_34 if consent_survey_mfi==1



gen no_contribution_hhinc_mfi = 1 if  MFI_RENEW_BL_1_22 ==5
recode no_contribution_hhinc_mfi (.= 0) if  MFI_RENEW_BL_1_22!=. & consent_survey_mfi==1
label variable no_contribution_hhinc_mfi "Respondent does not contribute at all to household earnings"

gen main_inc_earner_mfi = 1 if MFI_RENEW_BL_1_22==1 | MFI_RENEW_BL_1_22==2
recode main_inc_earner_mfi (.=0) if MFI_RENEW_BL_1_22!=. & consent_survey_mfi==1

label variable main_inc_earner_mfi "Respondent is the main earner"




gen earnings_unc_mfi = MFI_RENEW_BL_1_21 if consent_survey_mfi==1
recode earnings_unc_mfi (.=0) if MFI_RENEW_BL_1_21==. & consent_survey_mfi==1
label variable earnings_unc_mfi "Total earnings and profits (all income generating activities)"

gen earnings_cond_mfi =  MFI_RENEW_BL_1_21 if consent_survey_mfi==1
label variable earnings_cond_mfi "Total earnings and profits (all income generating activities)-Conditional"



***Rate business knowledge and skills
clonevar own_busskills_mfi =  MFI_RENEW_BL_1_29 if consent_survey_mfi==1
clonevar males_busskills_mfi =  MFI_RENEW_BL_1_30  if consent_survey_mfi==1
clonevar females_busskills_mfi =  MFI_RENEW_BL_1_31  if consent_survey_mfi==1


gen ever_took_loan_mfi = 1 if MFI_RENEW_BL_1_27==1
recode ever_took_loan_mfi (.=0) if MFI_RENEW_BL_1_27==2
label variable ever_took_loan_mfi "Respondent took a loan"

gen sole_decison_startbus_mfi = 1 if MFI_RENEW_BL_1_28==1
recode sole_decison_startbus_mfi (.= 0) if MFI_RENEW_BL_1_28 !=. & consent_survey_mfi==1
label variable sole_decison_startbus_mfi "Respondent does not need to ask permission from someone before making decision"



label variable age_resp_mfi "Age"
label variable married_resp_mfi  "Respondent is married"



*****Explicit Attitudes and Norms
**MFI sample
desc MFI_RENEW_BL_1_23 MFI_RENEW_FU_2_23





gen gen_att_strongagree_mfi = 1 if MFI_RENEW_BL_1_23==5
recode gen_att_strongagree_mfi (.= 0) if MFI_RENEW_BL_1_23!=.
label variable gen_att_strongagree_mfi "Men make better business executives than women do: Stronly Agree" 
label values gen_att_strongagree_mfi att_label2


gen gen_att_strongdis_mfi=1 if MFI_RENEW_BL_1_23==1
recode gen_att_strongdis_mfi (.= 0) if MFI_RENEW_BL_1_23!=.
lab var gen_att_strongdis_mfi "Men make better business executives than women do: SD"
label values gen_att_strongdis_mfi att_label3



gen gen_att_agree_neither_mfi=gen_att_agree_mfi
replace gen_att_agree_neither_mfi=1 if MFI_RENEW_BL_1_23==3
lab var gen_att_agree_neither_mfi "Men make better business executives than women do: Strongly agree/Agree/Neither" 
label define att_label5 0"Strongly disagree/Disagree" 1 "Strongly agree/Agree/Neither agree nor disagree"
label values gen_att_agree_neither_mfi att_label5




***Women should not enter occupations that are dominated by men

*SA
gen gen_att_strongagree2_mfi = 1 if MFI_RENEW_FU_2_23==5
recode gen_att_strongagree2_mfi (.= 0) if MFI_RENEW_FU_2_23!=.
label variable gen_att_strongagree2_mfi "Women should not enter occupations that are dominated by men: Stronly Agree" 
label define att_label1 0"Strongly disagree/disagree/Neither/Agree" 1 "Strongly agree"
label values gen_att_strongagree2_mfi att_label1


*A
gen gen_att_agree2_mfi = 1 if MFI_RENEW_FU_2_23==4 | MFI_RENEW_FU_2_23==5
recode gen_att_agree2_mfi (.= 0) if MFI_RENEW_FU_2_23!=.
label variable gen_att_agree2_mfi "Women should not enter occupations that are dominated by men: Agree" 
label define att_label2 0"Strongly disagree/disagree/Neither agree nor disagree" 1 "Strongly agree/Agree"
label values gen_att_agree2_mfi att_label2


*SD
gen gen_att_strdisagree2_mfi=1 if MFI_RENEW_FU_2_23==1 
recode gen_att_strdisagree2_mfi (.= 0) if MFI_RENEW_FU_2_23!=.
lab var gen_att_strdisagree2_mfi "Women should not enter occupation that are male dominated: SD"
label define att_label3 0"Disagree/Neither/Agree/Stronly agree" 1 "Strongly disagree"
label values gen_att_strdisagree2_mfi att_label3



*D
gen gen_att_disagree2_mfi=1 if (MFI_RENEW_FU_2_23==1  | MFI_RENEW_FU_2_23==2)
recode gen_att_disagree2_mfi (.= 0) if MFI_RENEW_FU_2_23!=.
lab var gen_att_disagree2_mfi "Women should not enter occupation that are male dominated: Disagree"
label define att_label4 0"Strongly disagree/Neither/Agree/Stronly agree" 1 "Disagree"
label values gen_att_disagree2_mfi att_label4


*COMBINED
gen explicit_sdisagree_mfi=0 if gen_att_strdisagree2_mfi!=. & gen_att_strongdis_mfi!=.
replace explicit_sdisagree_mfi=1 if gen_att_strdisagree2_mfi==1 | gen_att_strongdis_mfi==1
lab var explicit_sdisagree_mfi "Explicit attidue: SD "




********************************
****Neighbors bias
********************************

*** Out of 10 of your neighbors, how many do you think believe that women should not enter occupations that are dominated by men?
gen s_gen_norm2_mfi = MFI_RENEW_FU_2_24/10
gen gen_norm2_mfi = MFI_RENEW_FU_2_24*10
label variable s_gen_norm2_mfi "Percentage of neighbors who believe women should not enter MDO"
label variable gen_norm2_mfi "Out of 10 of your neighbors-Number of them believe women should not enter MDS"

/*
***Out of 10 of your neighbors - how many believe men make better business execs than women
gen s_gen_norm_mfi = MFI_RENEW_BL_1_24/10
gen gen_norm_mfi = MFI_RENEW_BL_1_24*10
label variable s_gen_norm_mfi "Percentage of neighbors who believe men make better business"
label variable gen_norm_mfi "Out of 10 of your neighbors-Number of them believe men make better business"
*/

gen neighbors_dummy_mfi=0 if s_gen_norm_mfi!=. & s_gen_norm2_mfi!=.
replace neighbors_dummy_mfi=1 if s_gen_norm_mfi>=0.5 & s_gen_norm2_mfi>=0.5
lab var neighbors_dummy_mfi "Out of 10 of your neighbors-More than 5 believe men make better business and women should not enter MDS"

gen gen_norm_dummy_mfi=0 if gen_norm_mfi!=.
replace gen_norm_dummy_mfi=1 if gen_norm_mfi>=50
lab var gen_norm_dummy_mfi "Number of neighbors think Men make better business: 5 or more"

gen gen_norm_dummy2_mfi=0 if gen_norm2_mfi!=.
replace gen_norm_dummy2_mfi=1 if gen_norm2_mfi>=50
lab var gen_norm_dummy2_mfi "Number of neighbors think Women should not enter MDS: 5 or more"

egen neighbors_bias_mfi=rowmean(MFI_RENEW_BL_1_24 MFI_RENEW_FU_2_24)
lab var neighbors_bias_mfi "Out of 10 of your neighbors, number with bias"
gen neighbors_bias_perc_mfi=neighbors_bias_mfi/10
lab var  neighbors_bias_perc_mfi "Percentage of bias neighbors"







/*

**Age bias (prefer young)
**On the whole, older men make better business executives than younger men do
gen age_att_disagree_mfi = 1 if MFI_RENEW_BL_1_25==1 | MFI_RENEW_BL_1_25==2 | MFI_RENEW_BL_1_25==3
recode age_att_disagree_mfi  (.= 0) if MFI_RENEW_BL_1_25!=.
label variable age_att_disagree_mfi  "Prefer young- Disagree older men make better business executives than younger"
label define dias_label 0"Agree" 1"Disagree"
label values age_att_disagree_mfi dias_label

**AGE BIAS
**On the whole, older men make better business executives than younger men do
gen age_att_agree_mfi = 1 if MFI_RENEW_BL_1_25==4 | MFI_RENEW_BL_1_25==5
recode age_att_agree_mfi  (.= 0) if MFI_RENEW_BL_1_25!=.
label variable age_att_agree_mfi "Older men make better business executives than younger men do"

**EDUCATION BIAS (prefer uni grads)
**On the whole, university graduates make better business executives than high school graduates
gen educ_att_agree_mfi = 1 if MFI_RENEW_BL_1_25==4 | MFI_RENEW_BL_1_25==5
recode educ_att_agree_mfi (.= 0) if MFI_RENEW_BL_1_25!=.

*/


gen mother_main_inc_earner_mfi=MFI_RENEW_FU_2_19==1
replace mother_main_inc_earner_mfi=. if MFI_RENEW_FU_2_19==.
lab var mother_main_inc_earner_mfi "Mother was main income earner"


gen father_main_inc_earner_mfi=MFI_RENEW_FU_2_19==2
replace father_main_inc_earner_mfi=. if MFI_RENEW_FU_2_19==.
lab var father_main_inc_earner_mfi "Father was main income earner"


gen mother_owned_bss_mfi=MFI_RENEW_FU_2_22==3
replace mother_owned_bss_mfi=. if MFI_RENEW_FU_2_22==.
lab var mother_owned_bss_mfi "Mother owned business, when you were a child"

gen father_owned_bss_mfi=MFI_RENEW_FU_2_21==3
replace father_owned_bss_mfi=. if MFI_RENEW_FU_2_21==.
lab var father_owned_bss_mfi "Father owned business, when you were a child"

gen sector_services_father_mfi=MFI_RENEW_FU_2_21b==4
replace sector_services_father_mfi=. if MFI_RENEW_FU_2_21b==.
label var sector_services_father_mfi  "Industry main business operate is services"


gen sector_services_mother_mfi=MFI_RENEW_FU_2_22b==4
replace sector_services_mother_mfi=. if MFI_RENEW_FU_2_22b==.
label var sector_services_mother_mfi  "Industry main business operate is services"


gen diff=MFI_RENEW_BL_1_30-MFI_RENEW_BL_1_31
gen no_difference_mfi=0 if diff!=.
replace no_difference_mfi=1 if diff==0
lab var no_difference_mfi "No difference in rating men and female business knowledge and skills"


gen male_better_mfi=0 if MFI_RENEW_BL_1_30!=. & MFI_RENEW_BL_1_31!=.
replace  male_better_mfi=1 if diff>0
ta diff male_better_mfi
lab var male_better_mfi "Males better skills(vs females/no difference)"

*** Compare male better vs female better (excluding no differece)
gen male_better_v2_mfi=male_better_mfi
replace male_better_v2_mfi=. if diff==0
lab var male_better_v2_mfi "Males better skills (vs female)"


gen female_better_mfi=0 if MFI_RENEW_BL_1_30!=. & MFI_RENEW_BL_1_31!=.
replace  female_better_mfi=1 if diff<0
ta diff female_better_mfi
lab var female_better_mfi "Females better skills (vs men/no diff)"

*** Compare female better vs male better (excluding no differece)
gen female_better_v2_mfi=female_better_mfi
replace female_better_v2_mfi=. if diff==0
lab var female_better_v2_mfi "Females better skills (vs males)"




save "$intermediatedata\Chigign_Tobiya_mfi_study_`today'.dta", replace



/*




