********************************************************************************************
********************************************************************************************
************************* IFWE Chigign Tobiya- Merging and reshaping ***********************

* Authors: Sreelakshmi Papineni and Emilia Cucagna, World Bank Africa Gender Innovation Lab
* Created on - November 09, 2022
* Project- IFWE Chigign Tobiya
* Purpose- This do file merges and reshapes IAT, TVET and MFI databases
* Steps: 
*		1- Merging the IAT score with the survey data
* 		2- Creating IAT score indicators
* Updated: June 2025
********************************************************************************************
********************************************************************************************


**********************************************************************************************
**********************************************************************************************
****** STEP 1- Merging the IAT score with the survey data
**********************************************************************************************
*********************************************************************************************

clear all

local today : di %tdDNCY daily("$S_DATE", "DMY")

use "$usingdata/IAT_DScore_Chigign_Tobiya_Clean.dta", clear

sort tvet_id
merge 1:1 tvet_id using "$intermediatedata\Chigign_Tobiya_TVET_Clean_`today'.dta"
rename _merge merge_tvet
gen type_resp=1
sort tvet_id
merge 1:1  tvet_id using "$intermediatedata\Chigign_Tobiya_mfi_study_`today'.dta", force
rename _merge merge_mfi
replace type_resp=2 if MFI_RENEW_BL_1_1!=""



***Geneerate identifiers
gen mfiofficer_identifier=0
replace mfiofficer_identifier=1 if MFI_RENEW_BL_1_1!=""
gen tvet_identifier=0
replace tvet_identifier=1 if female!=.


sort tvet_id 


************************************************************************************************************************
****** STEP 2- IAT scores indicators
************************************************************************************************************************
***Generate strong/moderate/slight/no association indicators
**absolute value >= .65 would indicate a "strong" association, it is not that case that any value below that would indicate *no association*. Instead, absolute values >= .35 are usually taken to indicate a "moderate" association, while >= .15 would indicate a "slight" effect.
**Anything between 0 and .15 would be taken as showing no association.
	  
gen IAT_words_created_D_score = 8 if IAT_words==8
recode IAT_words_created_D_score (.= 9) if IAT_words==9
recode IAT_words_created_D_score (.= 10) if IAT_words==10
recode IAT_words_created_D_score (.= 1) if IAT>-0.15 & IAT<0.15
recode IAT_words_created_D_score (.= 2) if IAT>=0.15 & IAT<0.35
recode IAT_words_created_D_score (.= 3) if IAT>=0.35 & IAT<0.65
recode IAT_words_created_D_score (.= 4) if IAT>=0.65 & IAT!=.
recode IAT_words_created_D_score (.= 5) if IAT>-0.35 & IAT<=-0.15
recode IAT_words_created_D_score (.= 6) if IAT>-0.65 & IAT<=-0.35
recode IAT_words_created_D_score (.= 7) if IAT<=-0.65 & IAT!=.


label define iatwords_ ///
4 "strong automatic association for Male with Career and Female with Family" ///
3 "moderate automatic association for Male with Career and Female with Family" ///
2 "slight automatic association for Male with Career and Female with Family" ///
1 "little or no automatic association between Female and Male with Career and Family" ///
5 "slight automatic association for Male with Family and Female with Career" ///
6 "moderate automatic association for Male with Family and Female with Career" ///
7 "strong automatic association for Male with Family and Female with Career" ///
8 "too many errors made to determine a result" ///
9 "too many fast trials to determine a result" ///
10 "not enough trials to determine a result"
label values IAT_words_created_D_score iatwords_

gen IAT_mod_strong_stereotype = 1 if IAT_words_created_D_score==3 | IAT_words_created_D_score==4 
recode IAT_mod_strong_stereotype (.=0) if IAT_words_created_D_score!=.
recode IAT_mod_strong_stereotype (0=.) if IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10

gen IAT_bias_stereotype = 1 if IAT_words_created_D_score==2 | IAT_words_created_D_score==3 | IAT_words_created_D_score==4 
recode IAT_bias_stereotype (.=0) if IAT_words_created_D_score!=.

gen IAT_strong_stereotype_old = 1 if IAT_words_created_D_score==4 
recode IAT_strong_stereotype_old (.=0) if IAT_words_created_D_score!=.
recode IAT_strong_stereotype_old (.=0) if IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10


*This variable basically codes the extremes as strongly implicitly gender biased (1), moderate or slight biased (2), or little or no bias (0). I have coded the ones without a successful trial as missing.  

gen IAT_strongstereotype = 1 if IAT_words_created_D_score==4 
recode IAT_strongstereotype (.=1) if IAT_words_created_D_score==7 
recode IAT_strongstereotype (.=2) if IAT_words_created_D_score==3 | IAT_words_created_D_score==2
recode IAT_strongstereotype (.=2) if IAT_words_created_D_score==5 | IAT_words_created_D_score==6
recode IAT_strongstereotype (.=0) if IAT_words_created_D_score==1
recode IAT_strongstereotype (*=.) if IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10


gen IAT_any_bias = 0 if IAT_words_created_D_score==1 
recode IAT_any_bias (.=1) if IAT_words_created_D_score!=.
recode IAT_any_bias (*=.) if IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10

gen IAT_strong_bias = 1 if IAT_words_created_D_score==4 | IAT_words_created_D_score==7 
recode IAT_strong_bias (.=0) if IAT_words_created_D_score!=.
recode IAT_strong_bias (.=0) if IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10

gen IAT_mod_strong_bias = 1 if IAT_words_created_D_score==4 | IAT_words_created_D_score==7 | IAT_words_created_D_score==3 | IAT_words_created_D_score==6
recode IAT_mod_strong_bias (.=0) if IAT_words_created_D_score!=.
recode IAT_mod_strong_bias (0=.) if IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10

gen IAT_strong_stereotype_2 = 1 if IAT_words==4 
recode IAT_strong_stereotype_2 (.=0) if IAT_words!=.
recode IAT_strong_stereotype_2 (0=.) if IAT_words==8 | IAT_words==9 | IAT_words==10

**IAT strong stereotype i.e. male career and female family
gen IAT_strong_stereotype_new = 1 if IAT_words_created_D_score==4 
recode IAT_strong_stereotype_new (.=0) if IAT_words_created_D_score!=.
recode IAT_strong_stereotype_new (0=.) if IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10

gen IAT_stereotype = 1 if IAT>=0.15 & IAT!=.
recode IAT_stereotype (.=0) if IAT_words_created_D_score!=.
recode IAT_stereotype (0=.) if IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10





***Save merged data
save "$intermediatedata/Chigign_Tobiya_IAT_TVET_MFI_Data_Clean_merged_`today'.dta", replace


**************************************************************************************************************************
**************************************************************************************************************************
* STEP 3- RESHAPING
**************************************************************************************************************************
**************************************************************************************************************************

***Reshaping the data to analyze the second video versus first video

use "$intermediatedata/Chigign_Tobiya_IAT_TVET_MFI_Data_Clean_merged_`today'.dta"


/*===================================================================================================*/
* STEP 3A- PREPARE DATA FOR RESHAPING
/*===================================================================================================*/


*********FOLLOW-UP 1_TVET

foreach var of varlist TVET_RENEW_FU_1_1_yesno TVET_RENEW_FU_1_2_yesno TVET_RENEW_FU_1_3 TVET_RENEW_FU_1_3_cond TVET_RENEW_FU_1_4 TVET_RENEW_FU_1_5_quality TVET_RENEW_FU_1_6_success TVET_RENEW_FU_1_7_risky TVET_RENEW_FU_1_8 TVET_RENEW_FU_1_9 TVET_RENEW_FU_1_10_yesno TVET_RENEW_FU_1_11_yesno TVET_RENEW_FU_1_12_yesno TVET_RENEW_FU_1_13_yesno TVET_RENEW_FU_1_14_yesno TVET_RENEW_FU_1_15_yesno TVET_RENEW_FU_1_16_yesno {
clonevar `var'_1 = `var'
}

*********FOLLOWUP_2_TVET
foreach var of varlist TVET_RENEW_FU_2_1_yesno TVET_RENEW_FU_2_2_yesno TVET_RENEW_FU_2_3 TVET_RENEW_FU_2_3_cond TVET_RENEW_FU_2_4 TVET_RENEW_FU_2_5_quality TVET_RENEW_FU_2_6_success TVET_RENEW_FU_2_7_risky TVET_RENEW_FU_2_8 TVET_RENEW_FU_2_9 TVET_RENEW_FU_2_10_yesno TVET_RENEW_FU_2_11_yesno TVET_RENEW_FU_2_12_yesno TVET_RENEW_FU_2_13_yesno TVET_RENEW_FU_2_14_yesno TVET_RENEW_FU_2_15_yesno TVET_RENEW_FU_2_16_yesno {
clonevar `var'_2 = `var'
}

rename TVET_RENEW_FU_2_1_yesno_2 TVET_RENEW_FU_1_1_yesno_2  
rename TVET_RENEW_FU_2_2_yesno_2 TVET_RENEW_FU_1_2_yesno_2
rename TVET_RENEW_FU_2_3_2 TVET_RENEW_FU_1_3_2
rename TVET_RENEW_FU_2_3_cond_2 TVET_RENEW_FU_1_3_cond_2
rename TVET_RENEW_FU_2_4_2 TVET_RENEW_FU_1_4_2
rename TVET_RENEW_FU_2_5_quality_2 TVET_RENEW_FU_1_5_quality_2
rename TVET_RENEW_FU_2_6_success_2 TVET_RENEW_FU_1_6_success_2
rename TVET_RENEW_FU_2_7_risky_2 TVET_RENEW_FU_1_7_risky_2
rename TVET_RENEW_FU_2_8_2 TVET_RENEW_FU_1_8_2
rename TVET_RENEW_FU_2_9_2 TVET_RENEW_FU_1_9_2
rename TVET_RENEW_FU_2_10_yesno_2 TVET_RENEW_FU_1_10_yesno_2
rename TVET_RENEW_FU_2_11_yesno_2 TVET_RENEW_FU_1_11_yesno_2 
rename TVET_RENEW_FU_2_12_yesno_2 TVET_RENEW_FU_1_12_yesno_2
rename TVET_RENEW_FU_2_13_yesno_2 TVET_RENEW_FU_1_13_yesno_2
rename TVET_RENEW_FU_2_14_yesno_2 TVET_RENEW_FU_1_14_yesno_2
rename TVET_RENEW_FU_2_15_yesno_2 TVET_RENEW_FU_1_15_yesno_2
rename TVET_RENEW_FU_2_16_yesno_2 TVET_RENEW_FU_1_16_yesno_2



*********FOLLOW-UP 1_MFI
foreach var of varlist MFI_RENEW_FU_1_1_yesno MFI_RENEW_FU_1_2_yesno MFI_RENEW_FU_1_3 MFI_RENEW_FU_1_3_cond MFI_RENEW_FU_1_4 MFI_RENEW_FU_1_5_quality MFI_RENEW_FU_1_6_success MFI_RENEW_FU_1_7_risky MFI_RENEW_FU_1_8 MFI_RENEW_FU_1_9 MFI_RENEW_FU_1_10_yesno MFI_RENEW_FU_1_11_yesno MFI_RENEW_FU_1_12_yesno MFI_RENEW_FU_1_13_yesno MFI_RENEW_FU_1_14_yesno MFI_RENEW_FU_1_15_yesno MFI_RENEW_FU_1_16_yesno {
clonevar `var'_1 = `var'
}


*********FOLLOW-UP 2_MFI
foreach var of varlist MFI_RENEW_FU_2_1_yesno MFI_RENEW_FU_2_2_yesno MFI_RENEW_FU_2_3 MFI_RENEW_FU_2_3_cond MFI_RENEW_FU_2_4 MFI_RENEW_FU_2_5_quality MFI_RENEW_FU_2_6_success MFI_RENEW_FU_2_7_risky MFI_RENEW_FU_2_8 MFI_RENEW_FU_2_9 MFI_RENEW_FU_2_10_yesno MFI_RENEW_FU_2_11_yesno MFI_RENEW_FU_2_12_yesno MFI_RENEW_FU_2_13_yesno MFI_RENEW_FU_2_14_yesno MFI_RENEW_FU_2_15_yesno MFI_RENEW_FU_2_16_yesno {
clonevar `var'_2 = `var'
}

rename MFI_RENEW_FU_2_1_yesno_2 MFI_RENEW_FU_1_1_yesno_2  
rename MFI_RENEW_FU_2_2_yesno_2 MFI_RENEW_FU_1_2_yesno_2
rename MFI_RENEW_FU_2_3_2 MFI_RENEW_FU_1_3_2
rename MFI_RENEW_FU_2_3_cond_2 MFI_RENEW_FU_1_3_cond_2
rename MFI_RENEW_FU_2_4_2 MFI_RENEW_FU_1_4_2
rename MFI_RENEW_FU_2_5_quality_2 MFI_RENEW_FU_1_5_quality_2
rename MFI_RENEW_FU_2_6_success_2 MFI_RENEW_FU_1_6_success_2
rename MFI_RENEW_FU_2_7_risky_2 MFI_RENEW_FU_1_7_risky_2
rename MFI_RENEW_FU_2_8_2 MFI_RENEW_FU_1_8_2
rename MFI_RENEW_FU_2_9_2 MFI_RENEW_FU_1_9_2
rename MFI_RENEW_FU_2_10_yesno_2 MFI_RENEW_FU_1_10_yesno_2
rename MFI_RENEW_FU_2_11_yesno_2 MFI_RENEW_FU_1_11_yesno_2 
rename MFI_RENEW_FU_2_12_yesno_2 MFI_RENEW_FU_1_12_yesno_2
rename MFI_RENEW_FU_2_13_yesno_2 MFI_RENEW_FU_1_13_yesno_2
rename MFI_RENEW_FU_2_14_yesno_2 MFI_RENEW_FU_1_14_yesno_2
rename MFI_RENEW_FU_2_15_yesno_2 MFI_RENEW_FU_1_15_yesno_2
rename MFI_RENEW_FU_2_16_yesno_2 MFI_RENEW_FU_1_16_yesno_2





sort tvet_id 

/*===================================================================================================*/
* STEP 3B- RESHAPE
/*===================================================================================================*/


reshape long TVET_RENEW_FU_1_1_yesno_ TVET_RENEW_FU_1_2_yesno_ TVET_RENEW_FU_1_3_ TVET_RENEW_FU_1_3_cond_ TVET_RENEW_FU_1_4_ TVET_RENEW_FU_1_5_quality_ TVET_RENEW_FU_1_6_success_ TVET_RENEW_FU_1_7_risky_ TVET_RENEW_FU_1_8_ TVET_RENEW_FU_1_9_ TVET_RENEW_FU_1_10_yesno_ TVET_RENEW_FU_1_11_yesno_ TVET_RENEW_FU_1_12_yesno_ TVET_RENEW_FU_1_13_yesno_ TVET_RENEW_FU_1_14_yesno_ TVET_RENEW_FU_1_15_yesno_ TVET_RENEW_FU_1_16_yesno_ MFI_RENEW_FU_1_1_yesno_ MFI_RENEW_FU_1_2_yesno_ MFI_RENEW_FU_1_3_ MFI_RENEW_FU_1_3_cond_ MFI_RENEW_FU_1_4_ MFI_RENEW_FU_1_5_quality_ MFI_RENEW_FU_1_6_success_ MFI_RENEW_FU_1_7_risky_ MFI_RENEW_FU_1_8_ MFI_RENEW_FU_1_9_ MFI_RENEW_FU_1_10_yesno_ MFI_RENEW_FU_1_11_yesno_ MFI_RENEW_FU_1_12_yesno_ MFI_RENEW_FU_1_13_yesno_ MFI_RENEW_FU_1_14_yesno_ MFI_RENEW_FU_1_15_yesno_ MFI_RENEW_FU_1_16_yesno_ , i(tvet_id) 



/*
tab videoclip _j

    Random |
 selection |          _j
  of video |         1          2 |     Total
-----------+----------------------+----------
         1 |       223        223 |       446 
         2 |       195        195 |       390 
         3 |       182        182 |       364 
         4 |       200        200 |       400 
         5 |       222        222 |       444 
         6 |       187        187 |       374 
         7 |       199        199 |       398 
         8 |       220        220 |       440 
-----------+----------------------+----------
     Total |     1,628      1,628 |     3,256 
*/

clonevar videoclip_all = videoclip
recode videoclip_all (1=9) if _j==2
recode videoclip_all (2=10) if _j==2
recode videoclip_all (3=11) if _j==2
recode videoclip_all (4=12) if _j==2
recode videoclip_all (5=13) if _j==2
recode videoclip_all (6=14) if _j==2
recode videoclip_all (7=15) if _j==2
recode videoclip_all (8=16) if _j==2

***This is the single test of the male video which didn't get an add-on to a second video
gen second_pitch = 0 if  videoclip_all==6
replace second_pitch = 1 if  videoclip_all==12

gen educfem_pitch = 0 if  videoclip_all==3
replace educfem_pitch = 1 if  videoclip_all==9

gen educmale_pitch = 0 if  videoclip_all==6
replace educmale_pitch = 1 if  videoclip_all==12

gen emofem_pitch = 0 if  videoclip_all==1
replace emofem_pitch = 1 if  videoclip_all==10

gen rolemodelfem_pitch = 0 if  videoclip_all==2
replace rolemodelfem_pitch = 1 if  videoclip_all==11

gen emomale_pitch = 0 if  videoclip_all==4
replace emomale_pitch = 1 if  videoclip_all==13

gen rolemodelmale_pitch = 0 if  videoclip_all==5
replace rolemodelmale_pitch = 1 if  videoclip_all==14

gen bademomale_pitch = 0 if  videoclip_all==6
replace bademomale_pitch = 1 if  videoclip_all==15

gen bademomale_pitch_sec = 0 if  videoclip_all==12
replace bademomale_pitch_sec = 1 if  videoclip_all==15

gen bademofem_pitch = 0 if  videoclip_all==3
replace bademofem_pitch = 1 if  videoclip_all==16
label variable bademofem_pitch "Good female construction vs bad female construction with emotional add on"

**MFI second video
clonevar rand_vid_all = rand_vid
recode rand_vid_all (1=3) if _j==2
recode rand_vid_all (2=4) if _j==2

des second_pitch educfem_pitch emofem_pitch rolemodelfem_pitch emomale_pitch rolemodelmale_pitch bademomale_pitch bademomale_pitch_sec bademofem_pitch

***************************************************************
***Including the second video in the analysis?
***************************************************************
gen sector_video_all = sector_video if _j==1
replace sector_video_all = 3 if videoclip_all==9
replace sector_video_all = 1 if videoclip_all==10
replace sector_video_all = 2 if videoclip_all==11
replace sector_video_all = 3 if videoclip_all==12
replace sector_video_all = 1 if videoclip_all==13
replace sector_video_all = 2 if videoclip_all==14
replace sector_video_all = 3 if videoclip_all==15
replace sector_video_all = 3 if videoclip_all==16

drop sector_video

label variable sector_video_all "Sector of both videos"
label values sector_video_all sector

gen second_video = 1 if _j==2
replace second_video = 0 if _j==1
label variable second_video "Second video"

gen educ_addon = 1 if  videoclip_all==9 
recode educ_addon (.= 0) if videoclip_all!=.
label variable educ_addon "Add on: Educational"

gen emo_addon = 1 if  videoclip_all==10 | videoclip_all==13 | videoclip_all==15 | videoclip_all==16  
recode emo_addon (.= 0) if videoclip_all!=.
label variable emo_addon "Add on: Emotional"

gen rolemodel_addon = 1 if  videoclip_all==11 | videoclip_all==14   
recode rolemodel_addon (.= 0) if videoclip_all!=.
label variable rolemodel_addon "Add on: Role model"

gen any_addon = 1 if  videoclip_all==9 | videoclip_all==10 | videoclip_all==13 | videoclip_all==15 | videoclip_all==16 | videoclip_all==11 | videoclip_all==14 
recode any_addon (.= 0) if videoclip_all!=.
label variable any_addon "Any add on"

******MFI database
gen sector_video_mfi_all = 1 if rand_vid_all==1 & _j==1
replace sector_video_mfi_all = 1 if rand_vid_all==2 & _j==1
replace sector_video_mfi_all = 3 if rand_vid_all==3 & _j==2
replace sector_video_mfi_all  = 3 if rand_vid_all==4 & _j==2
label variable sector_video_mfi_all "Sector MFI"



label variable sector_video_mfi_all "Sector of both videos (MFI)"
label values  sector_video_mfi_all sector

gen male_pitch_mfi = 1 if rand_vid_all== 2 | rand_vid_all == 4 
recode male_pitch_mfi (.=0) if rand_vid_all!=.

gen ever_bus_owner_mfi = 1 if MFI_RENEW_BL_1_19==1 | MFI_RENEW_BL_1_19==2
replace ever_bus_owner_mfi = 0 if MFI_RENEW_BL_1_19==3

label variable TVET_RENEW_BL_1_6 "Current sector course"
label variable TVET_RENEW_BL_1_6b "Curse level"



***Label variables

foreach var in TVET_RENEW_FU_1_1 MFI_RENEW_FU_1_10   MFI_RENEW_FU_1_11   MFI_RENEW_FU_1_12   MFI_RENEW_FU_1_13   MFI_RENEW_FU_1_14   MFI_RENEW_FU_1_15   MFI_RENEW_FU_1_16   MFI_RENEW_FU_1_1      TVET_RENEW_FU_1_10   TVET_RENEW_FU_1_11   TVET_RENEW_FU_1_12   TVET_RENEW_FU_1_13   TVET_RENEW_FU_1_14   TVET_RENEW_FU_1_15   TVET_RENEW_FU_1_16   {
	
local label : variable label `var'
label variable `var'_yesno_  "`label'"
}


foreach var in  TVET_RENEW_FU_1_9 TVET_RENEW_FU_1_3 TVET_RENEW_FU_1_4 TVET_RENEW_FU_1_5_quality TVET_RENEW_FU_1_6_success TVET_RENEW_FU_1_7_risky TVET_RENEW_FU_1_8 {
	
local label : variable label `var'
label variable `var'_  "`label'"

}


label variable TVET_RENEW_FU_1_3_cond "3. Cond. How much Birr do you think the tycoons should invest in this

foreach var in  TVET_RENEW_FU_1_3 TVET_RENEW_FU_1_3_cond TVET_RENEW_FU_2_3  {
	
local label : variable label `var'
label variable log_`var'  "`label'"

}

label variable TVET_RENEW_FU_1_3_cond_ "Conditional in thinking four business tycoons should invest, how much Birr?"
label variable TVET_RENEW_FU_1_3_cond_ "Conditional in thinking four business tycoons should invest, how much Birr?"
label variable TVET_RENEW_FU_1_5_quality_ "Quality of investment pitch"
label variable TVET_RENEW_FU_1_6_success_ "How successfull do you think this individual's business will be?"
label variable TVET_RENEW_FU_1_7_risky_  "How risky do you think this business idea is?"
label variable TVET_RENEW_FU_1_2_yesno_ "Do you think the four business tycoons should choose to invest in this business"
label variable TVET_RENEW_BL_1_5 "Place of interview"





*foreach var in age_att_disagree educ_att_agree gen_att_occ_seg_agree s_gen_occ_seg_norm gen_occ_seg_norm any_business_experience earnings_unc earnings_cond no_contribution_hhinc main_inc_earner ever_took_loan sole_decison_startbus mother_decision_maker father_decision_maker joint_decision_maker anyfem_decision_maker anymale_decision_maker mother_breadwinner father_breadwinner joint_breadwinner anyfem_breadwinner anymale_breadwinner any_rolemodel male_rolemodel female_rolemodel father_business_ownermgr mother_business_ownermgr mother_anywork male_admire_entrepreneur female_admire_entrepreneur{
*local label : variable label `var'_mfi
*label variable `var'  "`label'"

*}

**Graph on Sector X Male Pitch
clonevar sector_video_male_pitch = sector_video_all 
recode sector_video_male_pitch (1=4) if male_pitch==1
recode sector_video_male_pitch (2=5) if male_pitch==1
recode sector_video_male_pitch (3=6) if male_pitch==1


gen video_id=1 if _j==1
replace video_id=2 if _j==2
label variable video_id "Video ID


label variable tertiary_educ_tvet "Tertiary education"
label variable age_resp_tvet "Age"




label variable treatment_good_all "Good quality video vs bad quality video"
label define  bademomale_label1  0"Construction good male without emotional add on" 1"Construction bad male pitch with emo add on" 
label values  bademomale_pitch bademomale_label1
label variable bademomale_pitch  "Male bad pitch with emo add (1) vs male good pitch"
label variable educfem_pitch "Construction good Fem with edu (1) vs without edu)
label variable  emofem_pitch "Cafe good Fem with Emotional add on (1) vs without add on)
label variable paid_work "Worked for pay in the past month"
label variable TVET_RENEW_FU_1_5_quality_  "Quality of investment pitch (0-4)"
label variable TVET_RENEW_FU_1_6_success_  "How successfull do you think this individual's business will be? (0-4)"
label variable IAT_any_bias  "IAT any bias"
label variable IAT_stereotype  "IAT stereotype"



****Additional indicators
gen low_selfeff_v2=0 if selfeff!=.
replace low_selfeff_v2=1 if selfeff<=4.192568
label variable low_selfeff_v2 "Low self steem"

gen low_selfeff=0 if selfeff!=.
replace low_selfeff=1 if selfeff<=4
label variable low_selfeff "Low self steem"

gen own_busskills_above=0 if own_busskills!=.
replace own_busskills_above=1 if own_busskills>=5
label variable own_busskills_above "Respondent rate own business skills higher than average "

gen males_busskills_above=0 if males_busskills!=.
replace males_busskills_above=1 if males_busskills>=5
label variable males_busskills_above "Respondent rate male business skills higher than average "

gen females_busskills_above=0 if females_busskills!=.
replace females_busskills_above=1 if females_busskills>=5
label variable females_busskills_above "Respondent rate female business skills higher than average "

gen  tycoons_invest=TVET_RENEW_FU_1_2_yesno_
label variable tycoons_invest "Tycoons should choose to invest"

gen  tycoons_invest_amount=TVET_RENEW_FU_1_3_
label variable tycoons_invest_amount "Amount tycoons should invest"

gen  tycoons_invest_amount_cond=TVET_RENEW_FU_1_3_cond_
recode tycoons_invest_amount_cond (2=.)
label variable tycoons_invest_amount_cond "Amount tycoons should invest (conditional)"


gen  sector_bus_code=.
replace  sector_bus_code=0 if sector_bus==1
replace  sector_bus_code=1 if sector_bus==2
replace  sector_bus_code=0 if sector_bus==3
replace  sector_bus_code=1 if sector_bus==4
replace  sector_bus_code=1 if sector_bus==5
replace  sector_bus_code=1 if sector_bus==6
replace  sector_bus_code=1 if sector_bus==7
replace  sector_bus_code=0 if sector_bus==8
replace  sector_bus_code=1 if sector_bus==9
replace  sector_bus_code=1 if sector_bus==10
replace  sector_bus_code=0 if sector_bus==11
replace  sector_bus_code=0 if sector_bus==12
replace  sector_bus_code=0 if sector_bus==13
replace  sector_bus_code=0 if sector_bus==14
replace  sector_bus_code=0 if sector_bus==15
replace  sector_bus_code=0 if sector_bus==16

label variable sector_bus_code "Sector main business operate or aspire to is FCS"
label define sector_op 0"MDS" 1"FCS" 
label values sector_bus_code sector_op
 
***** adapt
gen TVET_RENEW_FU_2_3_cond2 = TVET_RENEW_FU_2_3 if TVET_RENEW_FU_2_2_yesno==1
label variable  TVET_RENEW_FU_2_3_cond2 "3. Cond. How much Birr do you think the tycoons should invest in this"
**************************
replace TVET_RENEW_FU_1_3_cond=TVET_RENEW_FU_2_3_cond2 if _j==2


gen treatment_bad_fem=0 if  treatment_bad_1==1
replace treatment_bad_fem=1 if  treatment_bad_1==0
label variable treatment_bad_fem "Male bad pitch (1) vs Female bad pitch"


gen schooling_1_12years=0 if TVET_RENEW_BL_1_16!=.
replace schooling_1_12years=1 if (TVET_RENEW_BL_1_16!=. & TVET_RENEW_BL_1_16>12)
label define years_schooling1 1 "12 or more years of schooling" 0 "1-11 year of schooling"
label values  schooling_1_12years   years_schooling1

gen high_earnings=0 if TVET_RENEW_BL_1_20!=.
 replace high_earnings=1 if  TVET_RENEW_BL_1_20!=. & TVET_RENEW_BL_1_20>2000
 label variable high_earnings "Total earnings are 2000 or above"
 label define high_earnings_label 1 "Total earnings are 2000 or above" 0 "Total earnings lower than 2000"
label values  high_earnings   high_earnings_label


gen father_head=0 if TVET_RENEW_BL_1_13!=.
replace  father_head=1 if TVET_RENEW_BL_1_13==4
label variable father_head "Father is head"

*** Good quality
gen goodquality_female=0 if (videoclip==4 |  videoclip==5 | videoclip==6)
replace goodquality_female=1  if (videoclip==1 |  videoclip==2 | videoclip==3)
label variable goodquality_female "Female good quality vs male good quality"

gen goodquality_male=0  if (videoclip==1 |  videoclip==2 | videoclip==3)
replace goodquality_male=1  & (videoclip==4 |  videoclip==5 | videoclip==6)

gen goodquality_female_femview=0 if goodquality_female!=. 
replace goodquality_female_femview=1 if  goodquality_female==1  & female==1

gen goodquality_male_femview=0 if goodquality_female!=. 
replace goodquality_male_femview=1 if  goodquality_female==1  & female==0



recode goodquality_male goodquality_female (0=.) if ( videoclip==7 | videoclip==8)


***************CHANGE MIND (video 1 vs video 2)
gen video1_no=0 if TVET_RENEW_FU_1_1_yesno_==0 & _j==1
bysort tvet_id: egen video1_no_max=max( video1_no)
gen video2_yes=1 if TVET_RENEW_FU_1_1_yesno_==1 & _j==2
bysort tvet_id: egen video2_yes_max=max( video2_yes)

gen change_mind=0 if video1_no_max==0
replace change_mind=1 if video1_no_max==0 & video2_yes_max==1


br tvet_id  video1_no video1_no_max TVET_RENEW_FU_1_1 _j tvet_identifier


tabstat change_mind if _j==2, by( female)
tabstat change_mind if _j==2, by( videoclip)
tabstat change_mind, by( videoclip) s(mean N)

	
	




gen quality_pitch_rating=TVET_RENEW_FU_1_4_
label variable quality_pitch_rating "Respondent rate quality of the pitch (Scale 0-10)"

gen pitch_quality=TVET_RENEW_FU_1_5_quality_
label variable pitch_quality "Pitch quality (0-4)"

gen pitch_success=TVET_RENEW_FU_1_6_success_ 
label variable  pitch_success "Business success in the future (0-4)"


gen pitch_risk=TVET_RENEW_FU_1_7_risky_ 
label variable  pitch_risk "Risky Business idea (0-4)"

gen entrepreneur_rating=TVET_RENEW_FU_1_8_ 
label variable entrepreneur_rating "Entrepreneur rating (0-10)"

gen entrepreneur_skills=TVET_RENEW_FU_1_9_ 
label variable entrepreneur_skills "Entrepreneur skills (0-10)"
 
gen entrepreneur_negotiator=TVET_RENEW_FU_1_10_yesno_ 
label variable  entrepreneur_negotiator "Entrepreneur is a good negotiator (0-1)"
 
gen entrepreneur_leader=TVET_RENEW_FU_1_11_yesno_ 
label variable  entrepreneur_leader "Entrepreneur is a good leader (0-1)"

gen entrepreneur_deal=TVET_RENEW_FU_1_12_yesno_ 
label variable entrepreneur_deal "Entrepreneur is a good manager (0-1)"
 
gen entrepreneur_info=TVET_RENEW_FU_1_13_yesno_ 
label variable entrepreneur_info "Entrepreneur provided enough info (0-1)"
 
gen video_enjoyed=TVET_RENEW_FU_1_14_yesno_ 
label variable video_enjoyed "Repondent enjoyed video (0-1)"
 
gen video_motivate=TVET_RENEW_FU_1_16_yesno_ 
label variable video_motivate "Repondent was motivated by the video (0-1)"
 
gen video_more=TVET_RENEW_FU_2_17_yesno 
label variable video_more "Repondent interested in furher episodes (0-1)"
 
gen learn_from_video= TVET_RENEW_FU_1_15_yesno_
label variable learn_from_video "Learned something from watching the video clip"
 
 
 *** Generate variable to measure gender bias by sector
 ***Cafe (all)
 gen bias_cafe=0 if sector_video_all==1 & (videoclip==4 | videoclip==5)
replace  bias_cafe=1 if sector_video_all==1 & (videoclip==1 | videoclip==2)

 ***Cafe (good and bad)
 gen bias_cafe_all=0 if sector_video_all==1 & (videoclip==4 | videoclip==5 | videoclip==7 )
replace  bias_cafe_all=1 if sector_video_all==1 & (videoclip==1 | videoclip==2 | videoclip==8)

 ***Construction (good only)
 gen bias_cons=0 if sector_video_all==3 & (videoclip==6| videoclip==4)
replace  bias_cons=1 if sector_video_all==3 & (videoclip==3 | videoclip==1)

 ***Construction (good and bad)
 gen bias_cons_all=0 if sector_video_all==3 & (videoclip==6| videoclip==4 | videoclip==7 )
replace  bias_cons_all=1 if sector_video_all==3 & (videoclip==3 | videoclip==1 | videoclip==8)

 ***text (all)
 gen bias_text=0 if sector_video_all==2 & (videoclip==5| videoclip==6)
replace  bias_text=1 if sector_video_all==2 & (videoclip==2 | videoclip==3)

label define bias_text_label 0 "Good pitch male in textile sector" 1 "Good pitch female in textile sector"
label define bias_cons_label 0 "Good pitch male in construction sector" 1 "Good pitch female in construction sector"
label define bias_cafe_label 0 "Good pitch male in Cafe sector" 1 "Good pitch female in Cafe sector"
label values bias_text bias_text_label
label values bias_cons bias_cons_label
label values bias_cafe bias_cafe_label
label define bias_cons_label2 0 "Good and bad pitch male in construction sector" 1 "Good and bad pitch female in construction sector"
label define bias_cafe_label2 0 "Good and bad pitch male in Cafe sector" 1 "Good and bad pitch female in Cafe sector"
label values bias_cons_all bias_cons_label2
label values bias_cafe_all bias_cafe_label2



label define l1 1 "Female good quality" 0 "Male good quality"
label values goodquality_female l1


gen viewer_connection=video_enjoyed+learn_from_video+video_motivate
label variable  viewer_connection "Viewer connection index"

gen entrepreneur_interpersonalskills=entrepreneur_negotiator+entrepreneur_leader+entrepreneur_deal
label variable  entrepreneur_interpersonalskills "Entrepreneur interpersonal skills index"

gen female_pitch=0 if male_pitch==1
replace female_pitch=1 if male_pitch==0
label variable male_pitch "Male pitch"
label variable female_pitch "Female pitch"

gen male=0 if female==1
replace male=1 if female==0
label variable male "Male viewer"
label variable female "Female viewer"


tab TVET_RENEW_BL_1_16 TVET_RENEW_BL_1_15
replace TVET_RENEW_BL_1_16=12 if TVET_RENEW_BL_1_16==1

rename entrepreneur_interpersonalskills ent_interpersonalskills


label define father_head  0"Father is not head" 1"Father is head"
label values father_head  father_head

label variable bad_pitch "Bad quality pitch (0-1)"


tabulate sector_video_all, generate(sector_)
label variable sector_1 "Cafe Business (FDS)"
label variable sector_2 "Textile Business (GNS)"
label variable sector_3 "Construction Business (MDS)"



label variable TVET_RENEW_FU_1_4_ "Quality of the investment pitch"
egen strata_tvet = group(TVET_RENEW_BL_1_8 TVET_RENEW_BL_1_6)
label var strata_tvet "Randomization strata - gender and sector"
label define strata 1 "Hotel and Tourism - Female" 2"Manufacturing - Female" 3"Textile - Female" 4 "Automotive - Female" 5"ICT - Female" 6"Surveying and Drafting - Female" 7"Electricity - Female" 8"Construction - Female" 9"Business - Female" 10"Accounting - Female" 11"Biomedical - Female" 12"Other -Female" 13"Manufacturing - Male" 14"Textile - Male" 15"Automotive - Male" 16"ICT - Male" 17"Surveying and Drafting - Male" 18"Electricity - Male" 19"Furniture Making - Male" 20"Construction - Male" 21"Business - Male" 22"Accounting - Male" 23"Biomedical - Male" 24"Building Construction -Male" 25"Health IT -Male", replace 
label values strata_tvet strata


***no association
gen no_association=IAT_words_created_D_score==1
replace no_association=. if IAT_words_created_D_score==. | IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10
lab var no_association "No Association between Female and Male with Career and Family"
label define no_a 1 "No Association between Female and Male with Career and Family" 0 "Any association"
label values no_association no_a

***no little association
gen no_little_association=0 if IAT_words_created_D_score!=.
replace no_little_association=1 if IAT_words_created_D_score==1 | IAT_words_created_D_score==2
replace no_little_association=. if  IAT_words_created_D_score==. | IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10	
lab var no_little_association "No or little association between Female and Male with Career and Family"

***mod strong association
gen mod_strong_association=0 if IAT_words_created_D_score!=. 
replace mod_strong_association=1 if IAT_words_created_D_score==3 | IAT_words_created_D_score==4
replace mod_strong_association=. if IAT_words_created_D_score==. | IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10
lab var mod_strong_association "Moderate strong association between Female and Male with Career and Family"

***strong association
gen strong_association=0 if IAT_words_created_D_score!=.
replace strong_association=1 if  IAT_words_created_D_score==4
replace strong_association=. if  IAT_words_created_D_score==. | IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10	
lab var strong_association "Strong association between Female and Male with Career and Family"

***Moderate association

gen moderate_association=0 if IAT_words_created_D_score!=.
replace moderate_association=1 if  IAT_words_created_D_score==3 | IAT_words_created_D_score==6
replace moderate_association=. if  IAT_words_created_D_score==. | IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10	
lab var moderate_association "Moderate association between Female and Male with Career and Family"



***IAT Strong v2
gen strong_association_v2=0 if IAT_words_created_D_score==1
replace strong_association_v2=1 if  IAT_words_created_D_score==4
lab var strong_association_v2 "Strong IAD association (vs little or no automatic) "

***IAT Strong v3
gen strong_association_v3=0 if IAT_words_created_D_score==1
replace strong_association_v3=1 if  IAT_words_created_D_score==4 | IAT_words_created_D_score==7
lab var strong_association_v3 "Strong IAD association (vs little or no automatic v3) "


save "$finaldata/Chigign_Tobiya_IAT_TVET_MFI_Data_Clean_merged.dta", replace




