*********************************************************************************************************
*Project: Chigign Tobiya Working Paper 

*Author: Sreelakshmi Papineni, World Bank Africa Gender Innovation Lab
*Date: June 2025

   *1- PREPARE DATA FOR ANALYSIS - creates datasets for both TVET and MFI analysis
   *2- SUMMARY STATISTICS: whole sample. Includes main indicators and characteristics of the respondents by gender
   *3- REGRESSION ANALYSIS - runs the tables for TVET and MFI samples
   
   **Replication data file for working paper "Gender Discrimination in Entrepreneurial Finance: Experimental Evidence from Ethiopia"

*********************************************************************************************************

* =============================================================================================== * 
* =============================================================================================== * 
*										IFWE Chigign Tobiya Ethiopia							  * 										   
* =============================================================================================== * 
* =============================================================================================== * 
/*

	
 	Outline: 	Table by table analysis code (main and appendix tables)
	                * Table 1: Investment Outcomes (Pure Gender Bias, Gender Homophily, and Heterogeneity by Sector)
					* Table 2: Entrepreneur Outcomes (Pure Gender Bias, Gender Homophily, and Heterogeneity by Sector)
					* Table 3: Heterogeneity Analysis by Implicit and Explicit Gender Bias, and Gender Norms		
					* Table 4: Impact of Experimental Role Model, Education, and Bad Quality Pitch
					* Table 5: MFI Sample - Investment, Entrepreneur and Business Outcomes
				    * Table A1: Experimental Design: Randomized Groups for TVET Students Sample (See Excel)
					* Table A2: Sample size of Strata for the TVET Students Randomized Sampling (See Excel)
				    * Table A3: Mean Differences in Characteristics of Youth Sample by Gender
					* Table A4: Mean Differences in Characteristics of MFI Credit Officers Sample by Gender
					* Figure A1: IAT Distribution Graph 


*/
* =============================================================================================== * 

	clear all 
	clear matrix 

	set maxvar 32000
	set matsize 11000
	
	set more off
	set varabbrev off
	
	local today : di %tdDNCY daily("$S_DATE", "DMY")
	
	version 17


* =============================================================================================== * 
* [ install necessary programs ] 
* =============================================================================================== * 
	local dlPrograms = 0
	if `dlPrograms' {
		ssc install ietoolkit, replace 
		ssc install diff, replace 
		net install st0026_2.pkg, replace
		ssc install texsave, replace
	}
	
	

* =============================================================================================== * 
* [ Root Folder Globals - Define User and Paths: set wd ] 
* =============================================================================================== * 
      
   * Assign User Number (Add more users as needed):
   * 1 - Sree
   * 2 - Other 

   * Set the user number for the current session:
   * gl user  1

   * Define Paths for Each User:
   * ------------------------------------
   *if $user == 1 {
       *global DIREC_MAIN "C:\Users\WB474637\OneDrive - WBG\SP WBG Data\Desktop\IFWE - RENEW Chigign\Discrimination Paper\ChigignTobiya_Replication"	
   *}
   
   *if $user == 2 {
       *global DIREC_MAIN "C:\Users\\`c(username)'\OneDrive - WBG"
   *}
	
	global DIREC_DTA     "${DIREC_MAIN}/Data"
	global DIREC_OUTPUT  "${DIREC_MAIN}/Output" 
    global DIREC_CODE    "${DIREC_MAIN}/Code" 
	
* =============================================================================================== * 
* [ create folders ]
* =============================================================================================== * 
	cd "${DIREC_MAIN}" 
	

* =============================================================================================== * 
* [ set path globals ]
* =============================================================================================== * 
	

	global setUp				1 // Has to be run always
	global blDiffTable_TVET 	1
    global blDiffTable_MFI		1
	global tvet                 1
	global tvet_1               1
	global tvet_2               1
	global tvet_3               1
	global tvet_4               1
	global tvet_5               1
	global mfi_1                1
    global mfi_2                1
	global mfi_3                1
	global mfi_4                1

	
	* Set up common globals
	global respChars age_resp_tvet tertiary_educ_tvet selfeff_std ///
	                 sector_services head_4 
					
	global blChars age_resp_tvet years_schooling married_resp_tvet selfeff_std ///
	                gen_att_agree age_att_agree educ_att_agree s_gen_norm gen_att_agree2 s_gen_norm2 no_association  ///
					paid_work aspiring_business_owner aspiring_wage_employee aspiring_other male_rolemodel female_rolemodel ///
					mother_breadwinner father_breadwinner 
					
					 
	global depvarList_inv tycoons_invest tycoons_invest_amount tycoons_invest_amount_cond  
	
	global depvarList_qual quality_pitch_rating pitch_quality pitch_success pitch_risk 
	
	global depvarList_char 	entrepreneur_rating entrepreneur_skills entrepreneur_negotiator entrepreneur_leader /// 
					        entrepreneur_deal entrepreneur_info viewer_connection
							
	global depvarList_all	tycoons_invest tycoons_invest_amount tycoons_invest_amount_cond pitch_success pitch_risk ///        
	                        entrepreneur_rating entrepreneur_skills ent_interpersonalskills entrepreneur_negotiator /// 
							entrepreneur_leader entrepreneur_deal  pitch_quality entrepreneur_info viewer_connection /// 
							video_enjoyed learn_from_video video_motivatevideo_enjoyed video_motivate video_more
					
	global covariates_economic any_business_experience paid_work earnings_unc earnings_cond ///
	                           no_contribution_hhinc main_inc_earner ever_took_loan
	
	global covariates_beliefs explicit_sdisagree  gen_att_strongagree  gen_att_agree  gen_att_strongdis gen_att_strongagree2 /// 
	                          gen_att_agree2 gen_att_disagree2 gen_att_strdisagree2 s_gen_norm s_gen_norm2 ///
							  neighbors_bias_perc educ_att_agree sole_decison_startbus age_att_agree /// 
							  aspiring_business_owner own_busskills_above males_busskills_above females_busskills_above ///  
							  no_difference male_better female_better male_better_v2 female_better_v2
	
	global covariates_famhistory mother_decision_maker father_decision_maker joint_decision_maker anyfem_decision_maker /// 
	                             anymale_decision_maker mother_breadwinner father_breadwinner joint_breadwinner /// 
								 anyfem_breadwinner anymale_breadwinner /// 
								 father_business_ownermgr mother_business_ownermgr any_business_owner mother_anywork 

	global covariates_role_model any_rolemodel male_rolemodel male_rolemodel2 female_rolemodel ///
	                             male_admire_entrepreneur female_admire_entrepreneur
								 
    global covariates_IAT 		 IAT_strongstereotype no_association IAT no_little_association /// 
	                             mod_strong_association strong_association  moderate_association IAT_strongstereotype_v2 
								 
    global controls_intervention educ_addon /*emo_addon*/ rolemodel_addon second_video bad_pitch
	
    global controls_demo  age_resp_tvet years_schooling any_business_experience sector_services

	global fe i.TVET_RENEW_BL_1_5 i.TVET_RENEW_BL_1_6 i.TVET_RENEW_BL_1_6b
	
    global controls_int_restrict educ_addon emo_addon second_video 
	
	global randomization_fe_mfi "i.mfi_branch i.position i.male"   
    
	global controls_demo_mfi "second_video age_resp_mfi years_schooling_mfi"
	
	global blChars_mfi age_resp_mfi years_schooling_mfi married_resp_mfi selfeff_std_mfi ///
	                gen_att_agree_mfi age_att_agree_mfi educ_att_agree_mfi s_gen_norm_mfi gen_att_agree2_mfi s_gen_norm2_mfi no_association  ///
					male_rolemodel_mfi female_rolemodel_mfi mother_breadwinner_mfi father_breadwinner_mfi


	
******************************
**# Set up the analysis data
******************************
if $setUp {
	
	***** Clean and merged dataset
	use "$DIREC_DTA/2_finaldata/Chigign_Tobiya_IAT_TVET_MFI_Data_Clean_merged.dta", clear
	
	
	/* 
		Notes about this dataset:

Contains the TVET and MFI samples together

	*/
	
	***** Make variables			
			
gen any_work=TVET_RENEW_BL_1_19
replace any_work=0 if TVET_RENEW_BL_1_19==2
lab var any_work "Worked for pay (at least one hour)"

gen years_schooling=TVET_RENEW_BL_1_16
lab var years_schooling "Education - number of years of schooling"

gen male_rolemodel2= male_rolemodel
replace  male_rolemodel2=. if TVET_RENEW_FU_2_20==3
lab var male_rolemodel2 "Male role model vs female role model"

gen any_business_owner=0 if father_business_ownermgr!=. | mother_business_ownermgr!=.
replace  any_business_owner=1 if father_business_ownermgr==1 | mother_business_ownermgr==1
lab var any_business_owner "Either mother or father were business owner"


gen mfi_officer=1 if MFI_RENEW_BL_1_1!=""
recode mfi_officer (.=0)
lab var mfi_officer "Respondent is an MFI credit officer"

gen  mfi_officer_male=1 if mfi_officer==1 & female_mfi==0
recode mfi_officer_male (.=0 ) if mfi_officer==1
lab var mfi_officer_male "Respondent is a Male MFI credit officer"

gen tvet=1 if tvet_id!=""
replace tvet=0 if  mfi_officer==1

gen tvet_female=0 if tvet==1
replace tvet_female=1 if female==1
lab var tvet_female "Respondent is Female from TVET sample"

recode MFI_RENEW_BL_1_14 (-999999999=.)
gen hh_size= TVET_RENEW_BL_1_12
replace hh_size= MFI_RENEW_BL_1_14 if hh_size==.

bysort tvet_id: gen identifier=_n

gen groups=1 if mfi_officer_male==1
replace groups=2 if mfi_officer_male==0
replace groups=3 if tvet_female ==0
replace groups=4 if tvet_female ==1
label define grouping 1 "Male MFI Officer"  2 "Female MFI Officer"   3 "Male TVET student"  4 "Female TVET student" 
label values  groups grouping

****Shorten labels
 
foreach i of varlist $covariates_beliefs  {
local longlabel: var label `i'
local shortlabel = substr(`"`longlabel'"',1,50)
label var `i' `"`shortlabel'"'
}


preserve
***keep only the relevant TVET variables
drop MFI_RENEW_BL_1_1- MFI_RENEW_FU_2_7_risky
drop MFI_endtime_0_0 tertiary_educ_mfi female_mfi age_resp_mfi married_resp_mfi self_hhhead_mfi num_children_mfi mother_decision_maker_mfi father_decision_maker_mfi joint_decision_maker_mfi anyfem_decision_maker_mfi anymale_decision_maker_mfi mother_breadwinner_mfi father_breadwinner_mfi joint_breadwinner_mfi anyfem_breadwinner_mfi anymale_breadwinner_mfi any_rolemodel_mfi male_rolemodel_mfi female_rolemodel_mfi father_business_ownermgr_mfi mother_business_ownermgr_mfi mother_anywork_mfi gen_att_occ_seg_agree_mfi s_gen_occ_seg_norm_mfi gen_occ_seg_norm_mfi pct_loan_app_females_mfi pct_loan_portfolio_females_mfi male_admire_entrepreneur_mfi female_admire_entrepreneur_mfi gen_att_agree_mfi s_gen_norm_mfi gen_norm_mfi age_att_disagree_mfi age_att_agree_mfi educ_att_agree_mfi any_business_experience_mfi selfeff_mfi selfeff_std_mfi group_loan_mfi msme_loan_mfi wedp_loan_mfi smefp_loan_mfi youthenterprise_loan_mfi business_loan_mfi personal_loan_mfi consumer_loan_mfi coopunion_loan_mfi other_loan_mfi num_loan_app_decision_mfi pct_time_with_customers_mfi no_contribution_hhinc_mfi main_inc_earner_mfi earnings_unc_mfi earnings_cond_mfi own_busskills_mfi males_busskills_mfi females_busskills_mfi ever_took_loan_mfi sole_decison_startbus_mfi merge_mfi mfiofficer_identifier MFI_RENEW_FU_1_1_yesno_ MFI_RENEW_FU_1_2_yesno_ MFI_RENEW_FU_1_3_ MFI_RENEW_FU_1_3_cond_ MFI_RENEW_FU_1_4_ MFI_RENEW_FU_1_5_quality_ MFI_RENEW_FU_1_6_success_ MFI_RENEW_FU_1_7_risky_ MFI_RENEW_FU_1_8_ MFI_RENEW_FU_1_9_ MFI_RENEW_FU_1_10_yesno_ MFI_RENEW_FU_1_11_yesno_ MFI_RENEW_FU_1_12_yesno_ MFI_RENEW_FU_1_13_yesno_ MFI_RENEW_FU_1_14_yesno_ MFI_RENEW_FU_1_15_yesno_ MFI_RENEW_FU_1_16_yesno_ sector_video_mfi_all male_pitch_mfi ever_bus_owner_mfi

***Order IAT vars
order IAT_words_created_D_score IAT_mod_strong_stereotype IAT_bias_stereotype IAT_strong_stereotype_old IAT_strongstereotype IAT_any_bias IAT_strong_bias IAT_mod_strong_bias IAT_strong_stereotype_2 IAT_strong_stereotype_new IAT_stereotype ,after(IAT)


*Generate interaction variables
gen inter_malepitch_maleviewer=male_pitch*male
label variable inter_malepitch_maleviewer "Male Pitch*Male Viewer"

gen inter_malepitch_mds=male_pitch*sector_3
label variable inter_malepitch_mds "Male Pitch*Construction Business (MDS)"

gen inter_malepitch_gns=male_pitch*sector_2
label variable inter_malepitch_gns "Male Pitch*Textile Business (GNS)"

gen inter_malepitch_fds=male_pitch*sector_1
label variable inter_malepitch_fds "Male Pitch*Cafe Business (FDS)"

gen inter_malepitch_gns_male=male_pitch*sector_2*male
label variable inter_malepitch_gns_male "Male Pitch*Textile Business (GNS)*Male"

gen inter_malepitch_mds_male=male_pitch*sector_3*male
label variable inter_malepitch_mds_male "Male Pitch*Construction Business (MDS)*Male"

gen iat_malepitch=IAT*male_pitch
lab var iat_malepitch "IAT*Male Pitch"

gen inter_malepitch_bad=male_pitch*bad_pitch
lab var inter_malepitch_bad "Male pitch*Bad Pitch"

gen inter_educ_male=male_pitch*educ_addon
lab var inter_educ_male "Male pitch*Education Add on"

gen inter_role_male=male_pitch*rolemodel_addon
lab var inter_role_male "Male pitch*Role model Add on"

 tab videoclip rolemodel_addon
 
 gen female_rolemodel_addon = 1 if rolemodel_addon==1 & videoclip==3
 gen male_rolemodel_addon = 1 if rolemodel_addon==1 & videoclip==6
 recode female_rolemodel_addon male_rolemodel_addon (.=0)

 gen inter_femalerole_male=male_pitch*female_rolemodel_addon
 lab var inter_femalerole_male "Male pitch*Female Role model Add on"

 gen inter_malerole_male=male_pitch*male_rolemodel_addon
 lab var inter_malerole_male "Male pitch*Male Role model Add on"

label var age_resp_tvet "Age of respondent (Years)"
label var years_schooling "Education Years of Schooling (Years)"
label var married_resp_tvet "Married (Yes=1; No=0)"
label var selfeff_std "Generalized self efficacy (standardized 0-1)"
label var gen_att_agree "Gender Att: % Agree men make better business execs than women"
label var age_att_agree "Age Att: % Disagree older men make better business execs than younger men"
label var educ_att_agree "Educ Att: % Agree uni grads make better business execs than highschool grads"
label var s_gen_norm "Norm: % of community believe men make better business executives than women"
label var gen_att_agree2 "Gender Att: % Agree women should not enter occupations dominated by men"
label var s_gen_norm2 "Norm: % of community believe women should not enter occupations dominated by men"
label var no_association "IAT: No Association between Female & Male with Career & Family (Yes=1; No=0)"
label var paid_work "Currently Engaged in Paid Work (Yes=1; No=0)"
label var aspiring_business_owner "Aspires to be a business owner when they graduate (Yes=1; No=0)"
label var aspiring_wage_employee "Aspires to work in wage employement when they graduate (Yes=1; No=0)"
label var aspiring_other "Aspires to work in other employment when they graduate (Yes=1; No=0)"
label var male_rolemodel "Had a male role model while growing up (Yes=1; No=0)"
label var female_rolemodel "Had a female role model while growing up (Yes=1; No=0)"
label var father_breadwinner "Breadwinner father: main income earner while growing up (Yes=1; No=0)"
label var mother_breadwinner "Breadwinner mother: main income earner while growing up (Yes=1; No=0)"

	***** Received vs not received
		label define female ///
        0 "Male" ///
        1 "Female"    
label values female female

*Heterogeneity interactions
gen inter_iat_male=IAT_strongstereotype*male_pitch
label var inter_iat_male "Male Pitch*IAT Strong stereotype"

lab variable IAT_strongstereotype "IAT Strong stereotype"

gen inter_mother_male=mother_main_inc_earner*male_pitch
lab variable inter_mother_male "Male Pitch*Mother Main income earner"

gen inter_att=gen_att_agree*male_pitch
lab variable inter_att "Male Pitch*Men better business executives"

gen inter_earnings=high_earnings*male_pitch
lab variable inter_earnings "Male Pitch*High earnings"

gen inter_aspiring_business_owner=aspiring_business_owner*male_pitch
lab variable inter_aspiring_business_owner "Male Pitch*Aspiring business owner"

gen inter_neighbors_dummy=neighbors_dummy*male_pitch
lab variable inter_neighbors_dummy "Male Pitch*Neighbors_dummy"

gen inter_nodiff_dummy=no_difference*male_pitch
lab variable inter_nodiff_dummy "Male Pitch*No difference in skills"

foreach var in head_4  any_work male_rolemodel2 mother_business_ownermgr father_business_ownermgr sole_decison_startbus sector_services neighbors_bias_perc head_3 male_rolemodel IAT_strongstereotype no_association no_little_association mod_strong_association strong_association    moderate_association strong_association_v2 strong_association_v3  male_better male_better_v2 female_better female_better_v2 explicit_sdisagree  gen_att_strongagree  gen_att_agree  gen_att_strongdis gen_att_strongagree2 gen_att_agree2  gen_att_disagree2 gen_att_strdisagree2 mother_decision_maker father_decision_maker joint_decision_maker anyfem_decision_maker anymale_decision_maker  mother_breadwinner father_breadwinner joint_breadwinner anyfem_breadwinner anymale_breadwinner    any_business_owner mother_anywork gen_norm_dummy gen_norm_dummy2 gen_att_agree_neither age_att_agree {
gen inter_`var'=`var'*male_pitch

local label : variable label `var'
label variable inter_`var'  "Male Pitch*`label'"
}

***Investment outcomes 
	clonevar yes_invest = tycoons_invest
	clonevar invest_amt =  tycoons_invest_amount
    clonevar invest_amt_cond = tycoons_invest_amount_cond

   gen s_invest_amt = invest_amt/1000
   gen s_invest_amt_cond = invest_amt_cond/1000
   
***Entrepreneur outcomes   
   clonevar ent_rate = entrepreneur_rating 
   clonevar ent_skills = entrepreneur_skills 
   clonevar ent_intskills = ent_interpersonalskills
	
***Business outcomes
   clonevar viewer_conn = viewer_connection
   
***Heterogeneity explicit gender attitudes
  gen gen_att_either = 1 if gen_att_agree==1 | gen_att_agree2==1
  recode gen_att_either (.=0) if gen_att_agree!=.
  
  gen gen_att_agree_new = 1 if  TVET_RENEW_BL_1_22==3 | TVET_RENEW_BL_1_22==4 | TVET_RENEW_BL_1_22==5
  recode gen_att_agree_new (.=0) if TVET_RENEW_BL_1_22!=.
  
  gen gen_att_strong = 1 if gen_att_agree==1
  recode gen_att_either (.=0) if gen_att_agree!=.
  
  *Create an index of both attitudes and code if strongly disagree
  egen gen_att_index = rowtotal(TVET_RENEW_BL_1_22 TVET_RENEW_FU_2_23)
  
  gen gen_att_strong_disagree = 1 if  gen_att_index==2
  recode gen_att_strong_disagree (.=0) if gen_att_agree!=.
  
  gen gen_att_index_agree = 1 if (TVET_RENEW_BL_1_22==4 | TVET_RENEW_BL_1_22==5) & (TVET_RENEW_FU_2_23==4 | TVET_RENEW_FU_2_23==5)
  recode gen_att_index_agree  (.=0) if gen_att_agree!=.
  
  
   *Create an index of both norms and code if low judgements expected
  egen gen_norm_index = rowtotal(gen_norm gen_norm2)
  recode gen_norm_index (*=.) if gen_norm ==.
  
  gen gen_norm_low = 1 if  gen_norm_index<60
  recode gen_norm_low (.=0) if gen_norm!=.
  
  
  **Set to zero if currently missing for those where an IAT was taken
  recode mod_strong_association (.=0) if IAT!=.
	
  gen inter_malepitch_modstrongass =male_pitch*mod_strong_association
  label variable inter_malepitch_modstrongass "Male Pitch*IAT Mod Strong"


 gen inter_malepitch_genattagree=male_pitch*gen_att_agree
 label variable inter_malepitch_genattagree "Male Pitch*GenAtt Agree"
 
 gen inter_malepitch_s_gen_norm=male_pitch*s_gen_norm
 label variable inter_malepitch_s_gen_norm "Male Pitch*Gen Norm"
 
  ***Relative skills
 gen rel_skill_male = 1 if TVET_RENEW_BL_1_32>TVET_RENEW_BL_1_33
 recode rel_skill_male (.=0) if TVET_RENEW_BL_1_32!=.

  gen inter_malepitch_rel_skill_male=male_pitch*rel_skill_male
 label variable inter_malepitch_rel_skill_male "Male Pitch*Rel Skills"

  
			tempfile dt_tvet 
			save `dt_tvet'
			
			restore
	
	***** Save separate datasets for TVET and MFI analysis

			preserve
keep *mfi* position rand_vid_all rand_vid MFI_endtime_0_0 MFI_RENEW_BL_1_1 MFI_RENEW_BL_1_3 MFI_RENEW_BL_1_5 MFI_starttime_0 MFI_endtime_0 MFI_RENEW_BL_0 MFI_RENEW_BL_1_2 MFI_RENEW_BL_1_4 MFI_RENEW_BL_1_4a MFI_RENEW_BL_1_4b MFI_RENEW_BL_1_4c MFI_RENEW_BL_1_6 MFI_RENEW_BL_1_6a MFI_RENEW_BL_1_7 MFI_RENEW_BL_1_7a MFI_RENEW_BL_1_17 MFI_RENEW_BL_1_17a MFI_RENEW_BL_1_9__Latitude MFI_RENEW_BL_1_9__Longitude MFI_RENEW_BL_1_9__Accuracy MFI_RENEW_BL_1_9__Altitude MFI_RENEW_BL_1_9__Timestamp MFI_RENEW_BL_1_10 MFI_RENEW_BL_1_11 MFI_RENEW_BL_1_12 MFI_RENEW_BL_1_12a MFI_RENEW_BL_1_13 MFI_RENEW_BL_1_14 MFI_RENEW_BL_1_15 MFI_RENEW_BL_1_16 MFI_RENEW_BL_1_18 MFI_RENEW_BL_1_8 MFI_RENEW_BL_1_8a MFI_RENEW_BL_1_19 MFI_RENEW_BL_1_20 MFI_RENEW_BL_1_21 MFI_RENEW_BL_1_22 MFI_RENEW_BL_1_23 MFI_RENEW_BL_1_24 MFI_RENEW_BL_1_25 MFI_RENEW_BL_1_26 MFI_RENEW_BL_1_27 MFI_RENEW_BL_1_28 MFI_RENEW_BL_1_29 MFI_RENEW_BL_1_30 MFI_RENEW_BL_1_31 MFI_RENEW_BL_1_32__1 MFI_RENEW_BL_1_32__2 MFI_RENEW_BL_1_32__3 MFI_RENEW_BL_1_32__4 MFI_RENEW_BL_1_32__5 MFI_RENEW_BL_1_32__6 MFI_RENEW_BL_1_32__7 MFI_RENEW_BL_1_32__8 MFI_RENEW_BL_1_32__9 MFI_RENEW_BL_1_32__10 MFI_RENEW_BL_1_32a MFI_RENEW_BL_1_33 MFI_RENEW_BL_1_34 MFI_RENEW_BL_1_35__1 MFI_RENEW_BL_1_35__2 MFI_RENEW_BL_1_35__3 MFI_RENEW_BL_1_35__4 MFI_RENEW_BL_1_35__5 MFI_RENEW_BL_1_35__6 MFI_RENEW_BL_1_35a MFI_RENEW_BL_1_36 MFI_RENEW_BL_1_37 MFI_RENEW_BL_1_38 MFI_RENEW_BL_1_39 MFI_RENEW_BL_1_40 MFI_RENEW_BL_1_41 MFI_RENEW_BL_1_42 MFI_RENEW_BL_1_43 MFI_RENEW_BL_1_44 MFI_RENEW_BL_1_45 MFI_RENEW_BL_00 MFI_RENEW_FU_1_00a MFI_RENEW_FU_1_00b MFI_RENEW_FU_0 MFI_RENEW_FU_1_1 MFI_RENEW_FU_1_3 MFI_RENEW_FU_1_4 MFI_RENEW_FU_1_5 MFI_RENEW_FU_1_6 MFI_RENEW_FU_1_7 MFI_RENEW_FU_1_8 MFI_RENEW_FU_1_9 MFI_RENEW_FU_1_10 MFI_RENEW_FU_1_11 MFI_RENEW_FU_1_12 MFI_RENEW_FU_1_13 MFI_RENEW_FU_1_14 MFI_RENEW_FU_1_15 MFI_RENEW_FU_1_16 MFI_RENEW_FU_00 MFI_RENEW_FU_2_00a MFI_RENEW_FU_2_00b MFI_RENEW_FU_2_00 MFI_RENEW_FU_2_1 MFI_RENEW_FU_2_2 MFI_RENEW_FU_2_3 MFI_RENEW_FU_2_4 MFI_RENEW_FU_2_5 MFI_RENEW_FU_2_6 MFI_RENEW_FU_2_7 MFI_RENEW_FU_2_8 MFI_RENEW_FU_2_9 MFI_RENEW_FU_2_10 MFI_RENEW_FU_2_11 MFI_RENEW_FU_2_12 MFI_RENEW_FU_2_13 MFI_RENEW_FU_2_14 MFI_RENEW_FU_2_15 MFI_RENEW_FU_2_16 MFI_RENEW_FU_2_17 MFI_RENEW_FU_2_18 MFI_RENEW_FU_2_18a MFI_RENEW_FU_2_19 MFI_RENEW_FU_2_19a MFI_RENEW_FU_2_20 MFI_RENEW_FU_2_21 MFI_RENEW_FU_2_21a MFI_RENEW_FU_2_21b MFI_RENEW_FU_2_21c MFI_RENEW_FU_2_21d MFI_RENEW_FU_2_21e MFI_RENEW_FU_2_21f MFI_RENEW_FU_2_21fg MFI_RENEW_FU_2_22 MFI_RENEW_FU_2_22a MFI_RENEW_FU_2_22b MFI_RENEW_FU_2_22c MFI_RENEW_FU_2_22d MFI_RENEW_FU_2_22e MFI_RENEW_FU_2_22f MFI_RENEW_FU_2_22fg MFI_RENEW_FU_2_23 MFI_RENEW_FU_2_24 MFI_RENEW_FU_2_25 MFI_RENEW_FU_2_26 MFI_RENEW_FU_2_27 MFI_RENEW_FU_2_28 MFI_RENEW_FU_2_0 MFI_RENEW_FU_1_1_yesno MFI_RENEW_FU_1_2_yesno MFI_RENEW_FU_1_10_yesno MFI_RENEW_FU_1_11_yesno MFI_RENEW_FU_1_12_yesno MFI_RENEW_FU_1_13_yesno MFI_RENEW_FU_1_14_yesno MFI_RENEW_FU_1_15_yesno MFI_RENEW_FU_1_16_yesno MFI_RENEW_FU_2_1_yesno MFI_RENEW_FU_2_2_yesno MFI_RENEW_FU_2_10_yesno MFI_RENEW_FU_2_11_yesno MFI_RENEW_FU_2_12_yesno MFI_RENEW_FU_2_13_yesno MFI_RENEW_FU_2_14_yesno MFI_RENEW_FU_2_15_yesno MFI_RENEW_FU_2_16_yesno MFI_RENEW_FU_2_17_yesno MFI_RENEW_FU_1_3_cond MFI_RENEW_FU_2_3_cond MFI_RENEW_FU_1_5_quality MFI_RENEW_FU_1_6_success MFI_RENEW_FU_1_7_risky MFI_RENEW_FU_2_5_quality MFI_RENEW_FU_2_6_success MFI_RENEW_FU_2_7_risky MFI_RENEW_FU_1_1_yesno_ MFI_RENEW_FU_1_2_yesno_ MFI_RENEW_FU_1_3_ MFI_RENEW_FU_1_3_cond_ MFI_RENEW_FU_1_4_ MFI_RENEW_FU_1_5_quality_ MFI_RENEW_FU_1_6_success_ MFI_RENEW_FU_1_7_risky_ MFI_RENEW_FU_1_8_ MFI_RENEW_FU_1_9_ MFI_RENEW_FU_1_10_yesno_ MFI_RENEW_FU_1_11_yesno_ MFI_RENEW_FU_1_12_yesno_ MFI_RENEW_FU_1_13_yesno_ MFI_RENEW_FU_1_14_yesno_ MFI_RENEW_FU_1_15_yesno_ MFI_RENEW_FU_1_16_yesno_ sector_video_mfi_all IAT IAT_words_created_D_score IAT_mod_strong_stereotype IAT_bias_stereotype IAT_strong_stereotype_old IAT_strongstereotype IAT_any_bias IAT_strong_bias IAT_mod_strong_bias IAT_strong_stereotype_2 IAT_strong_stereotype_new IAT_stereotype 


keep if mfiofficer_identifier==1
replace MFI_RENEW_BL_1_18=12 if MFI_RENEW_BL_1_18==1

replace female_mfi=. if female_mfi<0
lab var female_mfi "Female viewer"
recode female_mfi (2=0)
label define gender_01 0"Male" 1"Female"
label values female_mfi gender_01



recode MFI_RENEW_BL_1_10 -999999999 =.
recode MFI_RENEW_BL_1_18 -999999999 =.


lab var num_children_mfi "Number of children"



*label define sector_4 1"Female Cafe" 2"Male Cafe" 3"Female Construction" 4"Male Construction"
*label values  rand_vid_all sector_4

label define male_pitch 0"Female Pitch" 1"Male Pitch"
label values male_pitch_mfi  male_pitch

gen tycoons_invest_mfi= MFI_RENEW_FU_1_2_yesno_  
label variable tycoons_invest_mfi "Tycoons should choose to invest"

gen tycoons_invest_amount_mfi=MFI_RENEW_FU_1_3_
label variable tycoons_invest_amount_mfi "Amount tycoons should invest"

gen tycoons_invest_amount_cond_mfi=MFI_RENEW_FU_1_3_cond_
label variable tycoons_invest_amount_cond_mfi "Amount tycoons should invest (conditional)"

gen quality_pitch_rating_mfi=MFI_RENEW_FU_1_4_
label variable quality_pitch_rating_mfi "Respondent rate quality of the pitch (Scale 0-10)"

gen pitch_quality_mfi=MFI_RENEW_FU_1_5_quality_
label variable pitch_quality_mfi "Pitch quality (0-4)"

*replace pitch_quality_mfi=. if pitch_qual>4

gen pitch_success_mfi=MFI_RENEW_FU_1_6_success_
label variable pitch_success_mfi "Pitch success in the future (0-4)"
replace pitch_success_mfi=. if pitch_success_mfi>4

gen pitch_risk_mfi=MFI_RENEW_FU_1_7_risky_
label variable pitch_risk_mfi "Risky Business idea (0-4)"
replace pitch_risk_mfi=. if pitch_risk_mfi>4

gen  entrepreneur_rating_mfi=MFI_RENEW_FU_1_8_
label variable entrepreneur_rating_mfi "Entrepreneur rating (0-10)"

gen  entrepreneur_skills_mfi=MFI_RENEW_FU_1_9_
label variable entrepreneur_skills_mfi "Entrepreneur skills (0-10)"

gen entrepreneur_negotiator_mfi=MFI_RENEW_FU_1_10_yesno_
label variable entrepreneur_negotiator_mfi "Entrepreneur is a good negotiator (0-1)"

gen entrepreneur_leader_mfi=MFI_RENEW_FU_1_11_yesno_
label variable entrepreneur_leader_mfi "Entrepreneur is a good leader (0-1)"

gen entrepreneur_deal_mfi=MFI_RENEW_FU_1_12_yesno_ 
label variable entrepreneur_deal_mfi "Entrepreneur is a good manager (0-1)"

gen entrepreneur_info_mfi=MFI_RENEW_FU_1_13_yesno_
label variable entrepreneur_info_mfi "Entrepreneur provided enough info (0-1)"
 
gen  video_enjoyed_mfi =MFI_RENEW_FU_1_14_yesno_
label variable video_enjoyed_mfi "Repondent enjoyed video (0-1)"

gen video_motivate_mfi=MFI_RENEW_FU_1_15_yesno_
label variable video_motivate_mfi "Repondent was motivated by the video (0-1)"

gen  video_more_mfi=MFI_RENEW_FU_1_16_yesno_
label variable video_more_mfi "Repondent interested in furher episodes (0-1)"

gen learn_from_video_mfi= MFI_RENEW_FU_1_15_yesno_
label variable learn_from_video_mfi "Learned something from watching the video clip"
 
 
foreach var in tycoons_invest_mfi tycoons_invest_amount_mfi tycoons_invest_amount_cond_mfi quality_pitch_rating_mfi pitch_success_mfi pitch_risk_mfi entrepreneur_rating_mfi entrepreneur_skills_mfi entrepreneur_negotiator_mfi entrepreneur_leader_mfi entrepreneur_deal_mfi entrepreneur_info_mfi video_enjoyed_mfi video_motivate_mfi video_more_mfi pitch_quality_mfi{
replace `var'=. if  `var'<0
}



gen treatment_mfi=0 if rand_vid==2 & mfiofficer_identifier==1
replace treatment_mfi=1 if rand_vid==1 & mfiofficer_identifier==1
label define mfi_label 0"Male good quality pitch" 1"Female good quality pitch"
label values treatment_mfi mfi_label


gen male_sector_mfi=0 if sector_video_mfi_all!=.
replace  male_sector_mfi=1 if sector_video_mfi_all==3


gen viewer_connection_mfi=video_enjoyed_mfi+learn_from_video_mfi+video_motivate_mfi
label variable  viewer_connection_mfi "Viewer connection index"

gen entrepreneur_interkills_mfi=entrepreneur_negotiator_mfi+entrepreneur_leader_mfi+entrepreneur_deal_mfi
label variable  entrepreneur_interkills_mfi "Entrepreneur interpersonal skills index"


gen mds_male_mfi=0 if male_sector_mfi!=. & male_pitch_mfi!=.
replace mds_male_mfi=1 if male_sector_mfi==1 & male_pitch_mfi==1

gen mds_female_mfi=0 if male_sector_mfi!=. & male_pitch_mfi!=.
replace mds_female_mfi=1 if male_sector_mfi==1 & male_pitch_mfi==0



gen fcs_male_mfi=0 if male_sector_mfi==0 & male_pitch_mfi!=.
replace fcs_male_mfi=1 if male_sector_mfi==0 & male_pitch_mfi==1
label variable fcs_male_mfi "Male pitch in FCS (1) vs Female Pitch in FCS"

gen male_mfi=0 if MFI_RENEW_BL_1_10!=.
replace male_mfi=1 if MFI_RENEW_BL_1_10==0

gen inter_malepitch_maleviewer_mfi=male_pitch_mfi*male_sector_mfi
label variable inter_malepitch_maleviewer_mfi "Male Pitch*Male Viewer"


gen inter_malepitch_construction_mfi=male_pitch_mfi*male_sector_mfi
label variable inter_malepitch_construction_mfi "Male Pitch*Construction"

***IAT dummy variables
***no association
gen no_association=IAT_words_created_D_score==1
replace no_association=. if IAT_words_created_D_score==. | IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10
lab var no_association "No Association between Female and Male with Career and Family"
label values no_association no_a

***no little association
gen no_little_association=0 if IAT_words_created_D_score!=.
replace no_little_association=1 if IAT_words_created_D_score==1 | IAT_words_created_D_score==2
replace no_little_association=. if  IAT_words_created_D_score==. | IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10	
lab var no_little_association "No or little association between Female and Male with Career and Family"

***mod strong association
gen mod_strong_association=0 if IAT_words_created_D_score!=. 
replace mod_strong_association=1 if IAT_words_created_D_score==3 | IAT_words_created_D_score==4
replace mod_strong_association=. if IAT_words_created_D_score==. | IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10
lab var mod_strong_association "Moderate strong association between Female and Male with Career and Family"

***strong association
gen strong_association=0 if IAT_words_created_D_score!=.
replace strong_association=1 if  IAT_words_created_D_score==4
replace strong_association=. if  IAT_words_created_D_score==. | IAT_words_created_D_score==8 | IAT_words_created_D_score==9 | IAT_words_created_D_score==10	
lab var strong_association "Strong association between Female and Male with Career and Family"

  *Create an index of both attitudes and code if strongly disagree
  egen gen_att_index = rowtotal(MFI_RENEW_BL_1_23 MFI_RENEW_FU_2_23)
  
  gen gen_att_strong_disagree_mfi = 1 if  gen_att_index==2
  recode gen_att_strong_disagree_mfi (.=0) if gen_att_agree_mfi!=.
  
   *Create an index of both norms and code if low judgements expected
  egen gen_norm_index = rowtotal(gen_norm_mfi gen_norm2_mfi)
  recode gen_norm_index (*=.) if gen_norm_mfi ==.
  
  gen gen_norm_low_mfi = 1 if  gen_norm_index<60
  recode gen_norm_low_mfi (.=0) if gen_norm_mfi!=.
  
  
  **Male Pitch and Male dummies

   label variable male_pitch_mfi "Male Pitch"

   gen male = 1 if female_mfi == 0 
   recode male (.=0) if female_mfi==1

***Investment outcomes 
	clonevar tycoons_invest = tycoons_invest_mfi
	clonevar invest_amt_mfi =  tycoons_invest_amount_mfi
    clonevar invest_amt_cond_mfi = tycoons_invest_amount_cond_mfi

   gen s_invest_amt = invest_amt_mfi/1000
   gen s_invest_amt_cond = invest_amt_cond_mfi/1000
   
   
***MFI branch
   encode MFI_RENEW_BL_1_5, gen (mfi_branch) 
   
   
  gen years_schooling_mfi = MFI_RENEW_BL_1_18
  replace years_schooling_mfi = 0 if MFI_RENEW_BL_1_17==1
  
***Second video (drops out for the sector regression as construction is always in the second video for MFI sample)  
  gen second_video = 1 if rand_vid_all==3 | rand_vid_all==4
  recode second_video (.=0) if rand_vid_all!=.

  **Create a var for the 2 responses from each respondent
  bys MFI_RENEW_BL_1_1: gen num=_n
  
  
label var age_resp_mfi "Age of respondent (Years)"
label var years_schooling_mfi "Education Years of Schooling (Years)"
label var married_resp_mfi "Married (Yes=1; No=0)"
label var selfeff_std_mfi "Generalized self efficacy (standardized 0-1)"
label var gen_att_agree_mfi "Gender Att: % Agree men make better business execs than women"
label var age_att_agree_mfi "Age Att: % Disagree older men make better business execs than younger men"
label var educ_att_agree_mfi "Educ Att: % Agree uni grads make better business execs than highschool grads"
label var s_gen_norm_mfi "Norm: % of community believe men make better business executives than women"
label var gen_att_agree2_mfi "Gender Att: % Agree women should not enter occupations dominated by men"
label var s_gen_norm2_mfi "Norm: % of community believe women should not enter occupations dominated by men"
label var no_association "IAT: No Association between Female & Male with Career & Family (Yes=1; No=0)"
label var male_rolemodel_mfi "Had a male role model while growing up (Yes=1; No=0)"
label var female_rolemodel_mfi "Had a female role model while growing up (Yes=1; No=0)"
label var father_breadwinner_mfi "Breadwinner father: main income earner while growing up (Yes=1; No=0)"
label var mother_breadwinner_mfi "Breadwinner mother: main income earner while growing up (Yes=1; No=0)"

***Entrepreneur outcomes   
   clonevar ent_rate = entrepreneur_rating_mfi
   clonevar ent_skills = entrepreneur_skills_mfi 
   clonevar ent_intskills = entrepreneur_interkills_mfi
	
***Business outcomes
    clonevar pitch_success = pitch_success_mfi 
    clonevar pitch_risk = pitch_risk_mfi
    clonevar pitch_quality = pitch_quality_mfi
	
***Heterogeneity variables for gender attitudes and norms
    clonevar gen_att_agree = gen_att_agree_mfi 
    clonevar s_gen_norm = s_gen_norm_mfi
	
 **Set to zero if currently missing for those where an IAT was taken
  recode mod_strong_association (.=0) if IAT!=.
	
  gen inter_malepitch_modstrongass =male_pitch_mfi*mod_strong_association
  label variable inter_malepitch_modstrongass "Male Pitch*IAT Mod Strong"

 gen inter_malepitch_genattagree=male_pitch_mfi*gen_att_agree
 label variable inter_malepitch_genattagree "Male Pitch*GenAtt Agree"
 
 gen inter_malepitch_s_gen_norm=male_pitch_mfi*s_gen_norm
 label variable inter_malepitch_s_gen_norm "Male Pitch*Gen Norm"
 
 ***Relative skills
 gen rel_skill_male = 1 if MFI_RENEW_BL_1_30>MFI_RENEW_BL_1_31
 recode rel_skill_male (.=0) if MFI_RENEW_BL_1_30!=.

  gen inter_malepitch_rel_skill_male=male_pitch_mfi*rel_skill_male
 label variable inter_malepitch_rel_skill_male "Male Pitch*Rel Skills"


			tempfile dt_mfi
			save `dt_mfi'
restore			

			}



*********************************************************************************************************************************

*******************
*Table 1 - Investment outcomes pure gender bias, homophily and sector hetero
*******************
if $tvet_1 {
	
	use `dt_tvet', clear 
	
	eststo clear
	set more off 
	
	loc full_controls "$controls_intervention $controls_demo $fe"
 	local strata_fe "$fe"
	local checkmark "\checkmark"
	loc dv "tycoons_invest"
	loc dv2 "s_invest_amt"
    loc dv3 "s_invest_amt_cond"
	loc notes "*** p $<$ 0.01, ** p $<$ 0.05, * p $<$ 0.1. [1] Outcome variables: \textit{Tycoons should choose to invest} is a dummy variable equal to 1 if the viewer thinks the tycoons should invest in the idea, and equal to 0 if not. \textit{Amount tycoons should invest} is the proposed investment amount that the viewer thinks should be invested, and \textit{Amount tycoons should invest (conditional on investing)} is the amount conditional on investing. [2] \textit{Male Pitch} is a dummy variable equal to 1 if a male entrepreneur pitches the business idea and equal to 0 if a female entrepreneur pitches the idea. \textit{Male Viewer} is a dummy variable equal to 1 if the viewer is male and equal to 0 if the viewer is a female. Business sector dummy variables include \textit{Textile sector} if the business is in the gender-neutral textile sector, \textit{Construction sector} if the business is in the male-dominated construction sector, and the omitted business sector is the female-dominated food services (\textit{café and restaurant}) sector. [3] Ordinary Least Squares (OLS) regression specification with robust standard errors. [4] Controls include experimental design controls i.e. dummy variables indicating pitch quality, second video, and any experimental add-ons, and respondent demographic characteristics including age and years of schooling. Fixed effects for randomization strata include location of interview (TVET college) and TVET course subject and level."
	    
		loc lbl: variable label `dv'
	
			
		qui eststo: reg `dv' male_pitch `strata_fe', vce(robust)
					su `dv' if male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 
								estadd loc mD `mymean', replace							
								estadd loc statefe `checkmark', replace 	
								estadd loc controls "", replace 	
								
		qui eststo: reg `dv' male_pitch male inter_malepitch_maleviewer `full_controls', vce(robust)
					su `dv' if male_pitch==0 & male==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	

		qui eststo: reg `dv' male_pitch male sector_2 sector_3 inter_malepitch_gns inter_malepitch_mds `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_gns
					loc pval_gnsec: di %8.3f r(p)
					lincom male_pitch+inter_malepitch_mds
					loc pval_mdsec: di %8.3f r(p)
					su `dv' if male_pitch==0 & sector_1==1, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_gnsec', replace
								estadd loc pval2=`pval_mdsec', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
		qui eststo: reg `dv2'  male_pitch `strata_fe', vce(robust)
					su `dv2' if male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace 							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace 	
								
		qui eststo: reg `dv2' male_pitch male inter_malepitch_maleviewer `full_controls', vce(robust)
					su `dv2' if male_pitch==0 & male==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace 							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
		qui eststo: reg `dv2' male_pitch male sector_2 sector_3 inter_malepitch_gns inter_malepitch_mds `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_gns
					loc pval_gnsec: di %8.3f r(p)
					lincom male_pitch+inter_malepitch_mds
					loc pval_mdsec: di %8.3f r(p)
					su `dv2' if male_pitch==0 & sector_1==1, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_gnsec', replace
								estadd loc pval2=`pval_mdsec', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
								
		qui eststo: reg `dv3'  male_pitch `strata_fe', vce(robust)
					su `dv3' if male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace 					
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace 	
								
		qui eststo: reg `dv3' male_pitch male inter_malepitch_maleviewer `full_controls', vce(robust)
					su `dv3' if male_pitch==0 & male==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
		qui eststo: reg `dv3' male_pitch male sector_2 sector_3 inter_malepitch_gns inter_malepitch_mds `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_gns
					loc pval_gnsec: di %8.3f r(p)
					lincom male_pitch+inter_malepitch_mds
					loc pval_mdsec: di %8.3f r(p)
					su `dv3' if male_pitch==0 & sector_1==1, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace		
								estadd loc pval1=`pval_gnsec', replace
								estadd loc pval2=`pval_mdsec', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								

								
	loc dv_no_us = subinstr("`dv'", "_", "", . ) 
}
	
	#delimit ; 
	loc heading "Pure Gender Bias, Gender Homophily, and Heterogeneity By Sector"; 
    loc file "$DIREC_OUTPUT/chigigntobiya_`dv'.tex"; 

	
	loc resize 1.0; 
			esttab using "`file'", se r2 label compress replace obslast depvars nocons nomtitles nonum style(tex) fragment booktabs            cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch male inter_malepitch_maleviewer sector_2 sector_3 inter_malepitch_gns inter_malepitch_mds) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch "\hspace{-1mm}Male Pitch [A]" male "Male Viewer [B]" inter_malepitch_maleviewer "Male Pitch $\times\$ Male Viewer [C]" sector_2 "Textile Sector [D]" sector_3 "Construction Sector [E]" inter_malepitch_gns "Male Pitch $\times\$ Textile Sector [F]" inter_malepitch_mds "Male Pitch $\times\$ Construction Sector [G]") 	 		   
			s(N mD pval1 pval2, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch)" "p-value [A]+[F]" "p-value [A]+[G]")) 
			prehead(
				\begin{table}[!htbp] 
				\centering 
				\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
				\label{tab:LFPR`dv_no_us'}
				\caption{`heading'}  
				\subcaption*{\textbf{Investment Outcomes}}
				\label{tab:regTabInvestment}
				\begin{adjustbox}{width=\adjregTab\textwidth}
				\begin{tabular}{@{}l*{@M}{c}}\tabularnewline \hline \noalign{\medskip}
				&\multicolumn{3}{c}{\makecell{\text{Tycoons should choose} \\ {to invest} \\ {(Yes 1 No 0)}}}&\multicolumn{3}{c}{\makecell{\text{Investment Amount} \\ {Unconditional} \\ {(ETB in thousands)}}}&\multicolumn{3}{c}{\makecell{\text{Investment Amount} \\ {Conditional} \\ {(ETB in thousands)}}} \\\cmidrule(l){2-4}\cmidrule(l){5-7}\cmidrule(l){8-10}  
				& (1)  & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) \\ \cline{2-10}
				)
				posthead(\hline \noalign{\medskip}\)
				prefoot(\hline \noalign{\smallskip}
				)
				postfoot(\noalign{\smallskip}
				Controls & &  \checkmark & \checkmark  & &  \checkmark & \checkmark & &  \checkmark & \checkmark  \\
				Strata FE & \checkmark &  \checkmark & \checkmark  & \checkmark &  \checkmark & \checkmark & \checkmark &  \checkmark & \checkmark  \\
				\hline\hline \noalign{\smallskip}
			   	\end{tabular}
				}
				\medskip
				\begin{minipage}{`resize'\textwidth}
				\begin{tablenotes}
				{\footnotesize
				\item \textit{Note: @starlegend} 
				\item [1] [1] Outcome variables: \textit{Tycoons should choose to invest} is a dummy variable equal to 1 if the viewer thinks                              the tycoons should invest in the idea, and equal to 0 if not. \textit{Amount tycoons should invest} is the                              proposed investment amount that the viewer thinks should be invested, and \textit{Amount tycoons should invest                              (conditional)} is the amount conditional on investing. 
				\item [2] [2] \textit{Male Pitch} is a dummy variable equal to 1 if a male entrepreneur pitches the business idea and equal                               to 0 if a female entrepreneur pitches the idea. \textit{Male Viewer} is a dummy variable equal to 1 if the                               viewer is male and equal to 0 if the viewer is a female. Business sector dummy variables include \textit{                               Textile sector} if the business is in the gender-neutral textile sector, \textit{Construction sector} if the                               business is in the male-dominated construction sector, and the omitted business sector is the female-dominated                               food services (\textit{café and restaurant}) sector. 
				\item [3] [3] Ordinary Least Squares (OLS) regression specification with robust standard errors. 
				\item [4] [4] Controls include experimental design controls (pitch quality, second video, and experimental add-ons), and                              respondent characteristics including age and years of schooling.
				\item [5] [5] Fixed effects for randomization strata include location (TVET college), TVET course subject and level.
				}
                \end{tablenotes}
				\end{minipage}
				\end{adjustbox}
				\end{table}
				); 	
	#delimit cr 
	

*******************
*Table 2 - Entrepreneur and business outcomes pure gender bias, homophily and sector hetero
*******************
if $tvet_2 {
	
	use `dt_tvet', clear 
	
	eststo clear
	set more off 
	
	loc full_controls "$controls_intervention $controls_demo $fe"
 	local strata_fe "$fe"
	local checkmark "\checkmark"
	loc dv "ent_rate"
	loc dv2 "ent_skills"
    loc dv3 "ent_intskills"
    loc dv4 "pitch_risk"

		loc lbl: variable label `dv'
	
			
		qui eststo: reg `dv' male_pitch `strata_fe', vce(robust)
					su `dv' if male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe `checkmark', replace 	
								estadd loc controls "", replace 	
								
		qui eststo: reg `dv' male_pitch male inter_malepitch_maleviewer `full_controls', vce(robust)
					su `dv' if male_pitch==0 & male==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	

		qui eststo: reg `dv' male_pitch male sector_2 sector_3 inter_malepitch_gns inter_malepitch_mds `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_gns
					loc pval_gnsec: di %8.3f r(p)
					lincom male_pitch+inter_malepitch_mds
					loc pval_mdsec: di %8.3f r(p)
					su `dv' if male_pitch==0 & sector_1==1, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_gnsec', replace
								estadd loc pval2=`pval_mdsec', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
								
		qui eststo: reg `dv2'  male_pitch `strata_fe', vce(robust)
					su `dv2' if male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace 	
								
		qui eststo: reg `dv2' male_pitch male inter_malepitch_maleviewer `full_controls', vce(robust)
					su `dv2' if male_pitch==0 & male==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace 
								
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
		qui eststo: reg `dv2' male_pitch male sector_2 sector_3 inter_malepitch_gns inter_malepitch_mds `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_gns
					loc pval_gnsec: di %8.3f r(p)
					lincom male_pitch+inter_malepitch_mds
					loc pval_mdsec: di %8.3f r(p)
					su `dv2' if male_pitch==0 & sector_1==1, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace		
								estadd loc pval1=`pval_gnsec', replace
								estadd loc pval2=`pval_mdsec', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
								
		qui eststo: reg `dv3'  male_pitch `strata_fe', vce(robust)
					su `dv3' if male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace 							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace 	
								
		qui eststo: reg `dv3' male_pitch male inter_malepitch_maleviewer `full_controls', vce(robust)
					su `dv3' if male_pitch==0 & male==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace 							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
		qui eststo: reg `dv3' male_pitch male sector_2 sector_3 inter_malepitch_gns inter_malepitch_mds `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_gns
					loc pval_gnsec: di %8.3f r(p)
					lincom male_pitch+inter_malepitch_mds
					loc pval_mdsec: di %8.3f r(p)
					su `dv3' if male_pitch==0 & sector_1==1, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_gnsec', replace
								estadd loc pval2=`pval_mdsec', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								

		qui eststo: reg `dv4'  male_pitch `strata_fe', vce(robust)
					su `dv4' if male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace 							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace 	
								
		qui eststo: reg `dv4' male_pitch male inter_malepitch_maleviewer `full_controls', vce(robust)
					su `dv4' if male_pitch==0 & male==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace 							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
		qui eststo: reg `dv4' male_pitch male sector_2 sector_3 inter_malepitch_gns inter_malepitch_mds `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_gns
					loc pval_gnsec: di %8.3f r(p)
					lincom male_pitch+inter_malepitch_mds
					loc pval_mdsec: di %8.3f r(p)
					su `dv4' if male_pitch==0 & sector_1==1, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_gnsec', replace
								estadd loc pval2=`pval_mdsec', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace		
								
	loc dv_no_us = subinstr("`dv'", "_", "", . ) 
}
	
	#delimit ; 
	loc heading "Pure Gender Bias, Gender Homophily, and Heterogeneity By Sector"; 
    loc file "$DIREC_OUTPUT/chigigntobiya_`dv'.tex"; 

	
	loc resize 1.0; 
			esttab using "`file'", se r2 label compress replace obslast depvars nocons nomtitles nonum style(tex) fragment booktabs            cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch male inter_malepitch_maleviewer sector_2 sector_3 inter_malepitch_gns inter_malepitch_mds) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch "\hspace{-1mm}Male Pitch [A]" male "Male Viewer [B]" inter_malepitch_maleviewer "Male Pitch $\times\$ Male Viewer [C]" sector_2 "Textile Sector [D]" sector_3 "Construction Sector [E]" inter_malepitch_gns "Male Pitch $\times\$ Textile Sector [F]" inter_malepitch_mds "Male Pitch $\times\$ Construction Sector [G]") 	 		   
			s(N mD pval1 pval2, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch)" "p-value [A]+[F]" "p-value [A]+[G]")) 
			prehead(
				\begin{table}[!htbp] 
				\centering 
				\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
				\label{tab:LFPR`dv_no_us'}
				\caption{`heading'}  
				\subcaption*{\textbf{Entrepreneur and Business Perception Outcomes}}
				\label{tab:regTabInvestment}
				\begin{adjustbox}{width=\adjregTab\textwidth}
				\begin{tabular}{@{}l*{@M}{c}}\tabularnewline \hline \noalign{\medskip}
				&\multicolumn{3}{c}{\makecell{\text{Entrepreneur} \\ {overall rating} \\ {(Score 0-10)}}}&\multicolumn{3}{c}{\makecell{\text{Entrepreneur} \\ {knowledge and skills} \\ {(Score 0-10)}}}&\multicolumn{3}{c}{\makecell{\text{Entrepreneur} \\ {Interpersonal Skills} \\ {(Index 0-3)}}}&\multicolumn{3}{c}{\makecell{\text{Business idea} \\ {risk index} \\ {(Score 0-4)}}} \\\cmidrule(l){2-4}\cmidrule(l){5-7}\cmidrule(l){8-10}\cmidrule(l){5-7}\cmidrule(l){11-13}   
				& (1)  & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\ \cline{2-13}
				)
				posthead(\hline \noalign{\medskip}\)
				prefoot(\hline \noalign{\smallskip}
				)
				postfoot(\noalign{\smallskip}
				Controls & &  \checkmark & \checkmark  & &  \checkmark & \checkmark & &  \checkmark & \checkmark & &  \checkmark & \checkmark \\
				Strata FE & \checkmark &  \checkmark & \checkmark  & \checkmark &  \checkmark & \checkmark & \checkmark &  \checkmark & \checkmark & \checkmark & \checkmark &  \checkmark \\
				\hline\hline \noalign{\smallskip}
			   	\end{tabular}
				}
				\medskip
				\begin{minipage}{`resize'\textwidth}
				\begin{tablenotes}
				{\footnotesize
				\item \textit{Note: @starlegend} 
				\item [1] [1] Outcome variables: \textit{Entrepreneur overall rating} asks viewers to rate the entrepreneur on a scale from 0 to 10. \textit{Entrepreneur knowledge and skills} asks viewers to rate the entrepreneur's skills on a scale of 0-10, and \textit{Entrepreneur interpersonal skills} is an aggregated index that ranges from 0 to 3 calculated as the sum of three dummy variables for if the viewer perceives the entrepreneur as a good negotiator, good leader and good manager in business. \textit{Business idea risk level} measures how risky the respondent perceives the business idea to be on a scale of 0 (entirely risk-free) to 4 (very risky).
				\item [2] [2] \textit{Male Pitch} is a dummy variable equal to 1 if a male entrepreneur pitches the business idea and equal to 0 if a female entrepreneur pitches the idea. \textit{Male Viewer} is a dummy variable equal to 1 if the viewer is male and equal to 0 if the viewer is a female. Business sector dummy variables include \textit{Textile sector} if the business is in the gender-neutral textile sector, \textit{Construction sector} if the business is in the male-dominated construction sector, and the omitted business sector is the female-dominated food services (\textit{café and restaurant}) sector. 
				\item [3] [3] Ordinary Least Squares (OLS) regression specification with robust standard errors. 
				\item [4] [4] Controls include experimental design controls (pitch quality, second video, and experimental add-ons), and                              respondent characteristics including age and years of schooling.
				\item [5] [5] Fixed effects for randomization strata include location (TVET college), TVET course subject and level.
				}
                \end{tablenotes}
				\end{minipage}
				\end{adjustbox}
				\end{table}
				); 	
	#delimit cr 
	
	
*******************
*Table 3 - Heterogeneity by implicit/explit bias and gender norms
*******************
if $tvet_3 {
	
	use `dt_tvet', clear 
	
	eststo clear
	set more off 
	
	loc full_controls "$controls_intervention $controls_demo $fe"
 	local strata_fe "$fe"
	local demo_controls "$controls_demo"
	loc controls_int_few "$controls_int_restrict"
    loc strata_fe_exp "$controls_intervention $fe"
	local checkmark "\checkmark"
	loc dv "tycoons_invest"
	loc dv2 "s_invest_amt_cond"
    loc dv3 "ent_rate"
    loc dv4 "ent_skills"
    loc dv5 "ent_intskills"
    loc dv6 "pitch_risk"
	
		loc lbl: variable label `dv'
	
			
		qui eststo pA_dv_1: reg `dv' male_pitch mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
		su `dv' if male_pitch==0 & mod_strong_association==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pA_dv_2: reg `dv2' male_pitch mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust)
					lincom male_pitch+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv2' if male_pitch==0 & mod_strong_association==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pA_dv2_1: reg `dv3' male_pitch mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv3' if male_pitch==0 & mod_strong_association==0, mean 
					         loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pA_dv2_2: reg `dv4' male_pitch mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust)
					lincom male_pitch+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv4' if male_pitch==0 & mod_strong_association==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pA_dv3_1: reg `dv5' male_pitch mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv5' if male_pitch==0 & mod_strong_association==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace								

		qui eststo pA_dv3_2: reg `dv6' male_pitch mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv6' if male_pitch==0 & mod_strong_association==0, mean  
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace			
												
	
		qui eststo pB_dv_1: reg `dv' male_pitch gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv' if male_pitch==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pB_dv_2: reg `dv2' male_pitch gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv2' if male_pitch==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace		
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pB_dv2_1: reg `dv3' male_pitch gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv3' if male_pitch==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pB_dv2_2: reg `dv4' male_pitch gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv4' if male_pitch==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pB_dv3_1: reg `dv5' male_pitch gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv5' if male_pitch==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace								

		qui eststo pB_dv3_2: reg `dv6' male_pitch gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv6' if male_pitch==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
					
		qui eststo pC_dv_1: reg `dv' male_pitch s_gen_norm inter_malepitch_s_gen_norm `full_controls', vce(robust) 
					lincom male_pitch+inter_malepitch_s_gen_norm 
					loc pval_bias: di %8.3f r(p)
					su `dv' if male_pitch==0 & s_gen_norm==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pC_dv_2: reg `dv2' male_pitch s_gen_norm inter_malepitch_s_gen_norm `full_controls', vce(robust) 
		            lincom male_pitch+inter_malepitch_s_gen_norm 
					loc pval_bias: di %8.3f r(p)
					su `dv2' if male_pitch==0 & s_gen_norm==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pC_dv2_1: reg `dv3' male_pitch s_gen_norm inter_malepitch_s_gen_norm `full_controls', vce(robust) 
	             	lincom male_pitch+inter_malepitch_s_gen_norm 
					loc pval_bias: di %8.3f r(p)
					su `dv3' if male_pitch==0 & s_gen_norm==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace		
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pC_dv2_2: reg `dv4' male_pitch s_gen_norm inter_malepitch_s_gen_norm `full_controls', vce(robust) 
		            lincom male_pitch+inter_malepitch_s_gen_norm 
					loc pval_bias: di %8.3f r(p)
					su `dv4' if male_pitch==0 & s_gen_norm==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pC_dv3_1: reg `dv5' male_pitch s_gen_norm inter_malepitch_s_gen_norm `full_controls', vce(robust) 
		            lincom male_pitch+inter_malepitch_s_gen_norm 
					loc pval_bias: di %8.3f r(p)
					su `dv5' if male_pitch==0 & s_gen_norm==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace		
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace								

		qui eststo pC_dv3_2: reg `dv6' male_pitch s_gen_norm inter_malepitch_s_gen_norm `full_controls', vce(robust) 
		            lincom male_pitch+inter_malepitch_s_gen_norm 
					loc pval_bias: di %8.3f r(p)
					su `dv6' if male_pitch==0 & s_gen_norm==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
	loc dv_no_us = subinstr("`dv'", "_", "", . ) 
}
	
	#delimit ; 
	loc heading "Heterogeneity Analysis by Implicit and Explicit Gender Bias, and Gender Norms"; 
    loc file "$DIREC_OUTPUT/chigigntobiya_heteronew_`dv'.tex"; 

	
	loc resize 1.0; 
			esttab  pA_dv_1 pA_dv_2 pA_dv2_1 pA_dv2_2 pA_dv3_1 pA_dv3_2 using "`file'", se r2 label compress replace obslast depvars nocons nomtitles nonum style(tex) fragment booktabs            
			cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch mod_strong_association inter_malepitch_modstrongass) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch "\hspace{-1mm}Male Pitch [A]" mod_strong_association "Implicit Bias (IAT) [B]" inter_malepitch_modstrongass "Male Pitch $\times\$ Implicit Bias (IAT) [C]")  		   
			s(N mD pval1, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch No Bias)" "p-value [A]+[C]")) 
			prehead(
				\begin{table}[!htbp] 
				\centering 
				\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
				\label{tab:LFPR`dv_no_us'}
				\caption{`heading'}  
				\subcaption*{\textbf{Heterogeneity Analysis by measures of gender bias and perceived norms}}
				\vspace{-0.4cm}
				\label{tab:regTabInvestment}
				\begin{adjustbox}{width=\adjregTab\textwidth}
				\begin{tabular}{@{}l*{@M}{c}}\tabularnewline \hline \noalign{\medskip}
				&\multicolumn{1}{c}{\makecell{\text{Tycoons should} \\ {choose to invest} \\ {(Yes 1 No 0)}}}&\multicolumn{1}{c}{\makecell{\text{Investment Amount} \\ {Conditional} \\ {(ETB in thousands)}}}&\multicolumn{1}{c}{\makecell{\text{Entrepreneur} \\ {overall rating} \\ {(Score 0-10)}}}&\multicolumn{1}{c}{\makecell{\text{Entrepreneur} \\ {knowledge and skills} \\ {(Score 0-10)}}}&\multicolumn{1}{c}{\makecell{\text{Entrepreneur} \\ {Interpersonal Skills} \\ {(Index 0-3)}}}&\multicolumn{1}{c}{\makecell{\text{Business idea} \\ {risk index} \\ {(Score 0-4)}}} \\\cmidrule(l){2-3}\cmidrule(l){4-5}\cmidrule(l){6-7}\cmidrule(l){8-9}    
				& (1)  & (2) & (3) & (4) & (5) & (6)\\ \cline{2-7}
				)
				posthead(\hline \noalign{\medskip}
                \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel A (Implicit Gender Attitudes)}} \\
				\noalign{\medskip}
								 \\ [-3ex]
								 )
				prefoot(\hline \noalign{\medskip}
				)
				postfoot(\noalign{\smallskip}
												  )
			;			 
	#delimit cr 
	
				*** Panel B
				
		#delimit ;
				
				esttab pB_dv_1 pB_dv_2 pB_dv2_1 pB_dv2_2 pB_dv3_1 pB_dv3_2 
					   using "`file'", append style(tex) fragment booktabs label
           cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch gen_att_agree inter_malepitch_genattagree) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch "Male Pitch [A]" gen_att_agree "Explicit Bias (Attitude) [B]" inter_malepitch_genattagree "Male Pitch $\times\$ Explicit Bias (Attitude) [C]") 	 		   
			s(N mD pval1, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch No Bias)" "p-value [A]+[C]")) 
			    posthead("
						 		 \hline \\
								 \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel B (Explicit Gender Attitudes)}} \\
								 \noalign{\medskip}
								 \\ [-3ex]
								 ")	
				prefoot(\hline \noalign{\medskip}
				)
				postfoot(\noalign{\smallskip}
												  )
			;			 
	#delimit cr 		
								
				
				*** Panel C
	#delimit ;
				
				esttab pC_dv_1 pC_dv_2 pC_dv2_1 pC_dv2_2 pC_dv3_1 pC_dv3_2 
					   using "`file'", append style(tex) fragment booktabs label
           cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch s_gen_norm inter_malepitch_s_gen_norm) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch "Male Pitch [A]" s_gen_norm "Gender Norm [B]" inter_malepitch_s_gen_norm "Male Pitch $\times\$ Gender Norm [C]") 	 		   
			s(N mD pval1, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch No Perceived Bias)" "p-value [A]+[C]")) 
			    posthead("
						 		 \hline \\
								 \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel C (Perceived Gender Norms)}} \\
								 \noalign{\medskip}
								 \\ [-3ex]
								 ")	
				prefoot(\hline \noalign{\medskip}
				)
				postfoot(\noalign{\smallskip}
				Controls & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark  \\
				Strata FE & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark  \\
				\hline\hline \noalign{\smallskip}
			   	\end{tabular}
				}
				\medskip
				\begin{minipage}{`resize'\textwidth}
				\begin{tablenotes}
				{\footnotesize
				\item \textit{Note: @starlegend} 
				\item [1] [1] Gender Bias specification heterogeneity analysis by measures of gender bias. Panel A heterogeneity analysis by a dummy variable equal to 1 if the viewer had a moderate or strong stereotypical association between Male with Career and Female with Family in their Implicit Association Test (26\% of sample). Panel B by a dummy variable equal to 1 if the viewer personally strongly agrees or agrees that men make better executives than women do (31\% of sample). Panel C by a gender norm that is a continuous variable indicating the viewer's perception of the proportion of the community that think men make better business executives than women do.
				\item [2] [2] OLS regression specification with robust standard errors. 
				\item [3] [3] Controls include experimental design controls and respondent characteristics including gender, age and years of schooling. Fixed effects for randomization strata include location (TVET college), TVET course subject and level.
				
				}
                \end{tablenotes}
				\end{minipage}
				\end{adjustbox}
				\end{table}
				); 	
	#delimit cr 
		
*******************************************************	
		
	
*******************
*Table 4 - Role Model add-on, Education add-on, and Bad Quality Pitch analysis 
*******************
if $tvet_4 {
	
	use `dt_tvet', clear 
	
	eststo clear
	set more off 
	
	loc full_controls "$controls_intervention $controls_demo $fe"
 	local strata_fe "$fe"
	local demo_controls "$controls_demo"
	loc controls_int_few "$controls_int_restrict"
	local checkmark "\checkmark"
	loc dv "tycoons_invest"
	loc dv2 "s_invest_amt_cond"
    loc dv3 "ent_rate"
    loc dv4 "ent_skills"
    loc dv5 "ent_intskills"
    loc dv6 "pitch_risk"

		loc lbl: variable label `dv'
								
	
		qui eststo pA_dv_1: reg `dv' male_pitch rolemodel_addon inter_role_male male  `demo_controls' `strata_fe' if bad_pitch==0, vce(robust)
				    lincom male_pitch+inter_role_male 
					loc pval_role: di %8.3f r(p)
					su `dv' if male_pitch==0 & rolemodel_addon==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_role', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pA_dv_2: reg `dv2' male_pitch rolemodel_addon inter_role_male male  `demo_controls' `strata_fe' if bad_pitch==0, vce(robust) 
		            lincom male_pitch+inter_role_male 
					loc pval_role: di %8.3f r(p)
					su `dv2' if male_pitch==0 & rolemodel_addon==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_role', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pA_dv2_1: reg `dv3' male_pitch rolemodel_addon inter_role_male male `demo_controls' `strata_fe' if bad_pitch==0, vce(robust) 
		            lincom male_pitch+inter_role_male 
					loc pval_role: di %8.3f r(p)
					su `dv3' if male_pitch==0 & rolemodel_addon==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_role', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pA_dv2_2: reg `dv4' male_pitch rolemodel_addon inter_role_male male  `demo_controls' `strata_fe' if bad_pitch==0, vce(robust) 
		            lincom male_pitch+inter_role_male 
					loc pval_role: di %8.3f r(p)
					su `dv4' if male_pitch==0 & rolemodel_addon==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_role', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pA_dv3_1: reg `dv5' male_pitch rolemodel_addon inter_role_male male  `demo_controls' `strata_fe' if bad_pitch==0, vce(robust) 
		            lincom male_pitch+inter_role_male 
					loc pval_role: di %8.3f r(p)
					su `dv5' if male_pitch==0 & rolemodel_addon==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_role', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace								

		qui eststo pA_dv3_2: reg `dv6' male_pitch rolemodel_addon inter_role_male male  `demo_controls' `strata_fe' if bad_pitch==0, vce(robust) 
		            lincom male_pitch+inter_role_male 
					loc pval_role: di %8.3f r(p)
					su `dv3' if male_pitch==0 & rolemodel_addon==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_role', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace													
		qui eststo pB_dv_1: reg `dv' male_pitch educ_addon male `demo_controls' `strata_fe' if bad_pitch==0 & sector_3==1 & male_pitch==0, vce(robust) 
					su `dv' if bad_pitch==0 & sector_3==1 & male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pB_dv_2: reg `dv2' male_pitch educ_addon male `demo_controls' `strata_fe' if bad_pitch==0 & sector_3==1 & male_pitch==0, vce(robust) 
					su `dv2' if bad_pitch==0 & sector_3==1 & male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pB_dv2_1: reg `dv3' male_pitch educ_addon male `demo_controls' `strata_fe' if bad_pitch==0 & sector_3==1 & male_pitch==0, vce(robust) 
					su `dv3' if bad_pitch==0 & sector_3==1 & male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pB_dv2_2: reg `dv4' male_pitch educ_addon male `demo_controls' `strata_fe' if bad_pitch==0 & sector_3==1 & male_pitch==0, vce(robust)
					su `dv4' if bad_pitch==0 & sector_3==1 & male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pB_dv3_1: reg `dv5' male_pitch educ_addon male `demo_controls' `strata_fe' if bad_pitch==0 & sector_3==1 & male_pitch==0, vce(robust)
					su `dv5' if bad_pitch==0 & sector_3==1 & male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace								

		qui eststo pB_dv3_2: reg `dv6' male_pitch educ_addon male `demo_controls' `strata_fe' if bad_pitch==0 & sector_3==1 & male_pitch==0, vce(robust)
					su `dv6' if bad_pitch==0 & sector_3==1 & male_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
	
	
		qui eststo pC_dv_1: reg `dv' male_pitch bad_pitch inter_malepitch_bad `demo_controls' `strata_fe' `controls_int_few', vce(robust) 
				    lincom male_pitch+inter_malepitch_bad 
					loc pval_bad: di %8.3f r(p)
					su `dv' if male_pitch==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bad', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pC_dv_2: reg `dv2' male_pitch bad_pitch inter_malepitch_bad male  `demo_controls' `strata_fe' `controls_int_few', vce(robust) 
				    lincom male_pitch+inter_malepitch_bad 
					loc pval_bad: di %8.3f r(p)
					su `dv2' if male_pitch==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bad', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pC_dv2_1: reg `dv3' male_pitch bad_pitch inter_malepitch_bad male  `demo_controls' `strata_fe' `controls_int_few', vce(robust) 
			        lincom male_pitch+inter_malepitch_bad 
					loc pval_bad: di %8.3f r(p)
					su `dv3' if male_pitch==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_bad', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pC_dv2_2: reg `dv4' male_pitch bad_pitch inter_malepitch_bad male `demo_controls' `strata_fe' `controls_int_few', vce(robust) 
				    lincom male_pitch+inter_malepitch_bad 
					loc pval_bad: di %8.3f r(p)
					su `dv4' if male_pitch==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_bad', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pC_dv3_1: reg `dv5' male_pitch bad_pitch inter_malepitch_bad male  `demo_controls' `strata_fe' `controls_int_few', vce(robust) 
				    lincom male_pitch+inter_malepitch_bad 
					loc pval_bad: di %8.3f r(p)
					su `dv5' if male_pitch==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bad', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace								

		qui eststo pC_dv3_2: reg `dv6' male_pitch bad_pitch inter_malepitch_bad male `demo_controls' `strata_fe' `controls_int_few', vce(robust) 
				    lincom male_pitch+inter_malepitch_bad 
					loc pval_bad: di %8.3f r(p)
					su `dv6' if male_pitch==0 & bad_pitch==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bad', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
	
								
	loc dv_no_us = subinstr("`dv'", "_", "", . ) 
}
	
	#delimit ; 
	loc heading "Impact of Experimental Role Model, Education, and Bad Quality Pitch"; 
    loc file "$DIREC_OUTPUT/chigigntobiya_addons_`dv'.tex"; 

	
	loc resize 1.0; 
			esttab  pA_dv_1 pA_dv_2 pA_dv2_1 pA_dv2_2 pA_dv3_1 pA_dv3_2 using "`file'", se r2 label compress replace obslast depvars nocons nomtitles nonum style(tex) fragment booktabs            
			cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch rolemodel_addon inter_role_male) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch "Male Pitch [A]" rolemodel_addon "Role Model Add-on [B]" inter_role_male "Male Pitch $\times\$ Role Model Add-on [C]") 	 		   
			s(N mD pval1, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch No Add-on)" "p-value [A]+[C]")) 
			prehead(
				\begin{table}[!htbp] 
				\centering 
				\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
				\label{tab:LFPR`dv_no_us'}
				\caption{`heading'}  
				\subcaption*{\textbf{Impact of Role Model, Education, and Pitch Quality Experiments}}
				\vspace{-0.4cm}
				\label{tab:regTabInvestment}
				\begin{adjustbox}{width=\adjregTab\textwidth}
				\begin{tabular}{@{}l*{@M}{c}}\tabularnewline \hline \noalign{\medskip}
				&\multicolumn{1}{c}{\makecell{\text{Tycoons should} \\ {choose to invest} \\ {(Yes 1 No 0)}}}&\multicolumn{1}{c}{\makecell{\text{Investment Amount} \\ {Conditional} \\ {(ETB in thousands)}}}&\multicolumn{1}{c}{\makecell{\text{Entrepreneur} \\ {overall rating} \\ {(Score 0-10)}}}&\multicolumn{1}{c}{\makecell{\text{Entrepreneur} \\ {knowledge and skills} \\ {(Score 0-10)}}}&\multicolumn{1}{c}{\makecell{\text{Entrepreneur} \\ {Interpersonal Skills} \\ {(Index 0-3)}}}&\multicolumn{1}{c}{\makecell{\text{Business idea} \\ {risk index} \\ {(Score 0-4)}}} \\\cmidrule(l){2-3}\cmidrule(l){4-5}\cmidrule(l){6-7}\cmidrule(l){8-9}    
				& (1)  & (2) & (3) & (4) & (5) & (6) \\ \cline{2-7}

				)
				posthead(\hline \noalign{\medskip}
                \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel A (Role Model Add-on)}} \\
				\noalign{\medskip}
								 \\ [-3ex]
								 )
				prefoot(\hline \noalign{\medskip}
				)
				postfoot(\noalign{\smallskip}
												  )
			;			 
	#delimit cr 
	
					*** Panel B
				
		#delimit ;
				
				esttab pB_dv_1 pB_dv_2 pB_dv2_1 pB_dv2_2 pB_dv3_1 pB_dv3_2 
					   using "`file'", append style(tex) fragment booktabs label
           cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(educ_addon) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(educ_addon "Education Add-on") 	 		   
			s(N mD, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch No Add-on)")) 
			    posthead("
						 		 \hline \\
								 \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel B (Education Add-on Construction)}} \\
								 \noalign{\medskip}
								 \\ [-3ex]
								 ")	
				prefoot(\hline \noalign{\medskip}
				)
				postfoot(\noalign{\smallskip}
												  )
			;			 
	#delimit cr 	
	
				*** Panel C
				
		#delimit ;
				
				esttab pC_dv_1 pC_dv_2 pC_dv2_1 pC_dv2_2 pC_dv3_1 pC_dv3_2 
					   using "`file'", append style(tex) fragment booktabs label
           cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch bad_pitch inter_malepitch_bad) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch "Male Pitch [A]" bad_pitch "Bad Quality Pitch [B]" inter_malepitch_bad "Male Pitch $\times\$ Bad Quality Pitch [C]") 	 		   
			s(N mD pval1, fmt(%9.0fc) labels("Obs" "Base Mean (Female Good Quality Pitch)" "p-value [A]+[C]")) 
			    posthead("
						 		 \hline \\
								 \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel C (Quality of the Pitch Experiment)}} \\
								 \noalign{\medskip}
								 \\ [-3ex]
								 ")	
				prefoot(\hline \noalign{\medskip}
				)
				postfoot(\noalign{\smallskip}
				Controls & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark  \\
				Strata FE & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark \\
				\hline\hline \noalign{\smallskip}
			   	\end{tabular}
				}
				\medskip
				\begin{minipage}{`resize'\textwidth}
				\begin{tablenotes}
				{\footnotesize
				\item \textit{Note: @starlegend} 
				\item [1] [1] Panel A \textit{role model add-on} experiment sample restricted to the good pitch quality videos only. Panel B \textit{education add-on} experiment sample restricted to the good pitch quality in construction sector videos only. In Panel C \textit{bad quality pitch} experiment includes the full study sample. 
				\item [2] [2] OLS regression specification with robust standard errors. 
				\item [3] [3] Controls include experimental design controls and respondent characteristics including gender, age and years of schooling. Fixed effects for randomization strata.
				}
                \end{tablenotes}
				\end{minipage}
				\end{adjustbox}
				\end{table}
				); 	
	#delimit cr 
	
	
		
*******************************************************		



********************************************
**# Table A3 - Baseline Characteristics
********************************************
if $blDiffTable_TVET {
	
	
	use `dt_tvet', clear 
	
	***** Table on characteristics for TVET sample
		sum $blChars 		
		
		iebaltab $blChars if _j==1, grpvar(female) ///
			total order(0 1) rowvarlabels tblnonote addnote("* 0.1 ** 0.05 *** 0.01. Value for t-tests are the differences in means across genders") ///
			savetex("$DIREC_OUTPUT\blTest_gender_tvet.tex") replace
					

}		

********************************************
**# Table A4 - Baseline Characteristics
********************************************
if $blDiffTable_MFI {
	
	
	use `dt_mfi', clear 
	
	***** Table on characteristics for MFI sample
		sum $blChars_mfi 		
		
		iebaltab $blChars_mfi if num==1, grpvar(female_mfi) ///
			total order(0 1) rowvarlabels tblnonote addnote("* 0.1 ** 0.05 *** 0.01. Value for t-tests are the differences in means across genders") ///
			savetex("$DIREC_OUTPUT\blTest_gender_mfi.tex") replace
					

}		
	
*******************
*Table 5 - MFI officers- Investment, Entrepreneur and Business outcomes pure gender bias
*******************	
	
if $mfi_1 {
	
	use `dt_mfi', clear 
		
	eststo clear
	set more off 	
	
	loc full_controls "$controls_demo_mfi $randomization_fe_mfi male"
 	local strata_fe "$randomization_fe_mfi"
	local checkmark "\checkmark"
	loc dv "tycoons_invest"
	loc dv2 "s_invest_amt_cond"
    loc dv3 "ent_rate"
    loc dv4 "ent_skills"
    loc dv5 "ent_intskills"
    loc dv6 "pitch_risk"
	
		loc lbl: variable label `dv'
	
			
		qui eststo pA_dv_1: reg `dv' male_pitch_mfi `full_controls', vce(robust) 
					su `dv' if male_pitch_mfi==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
		qui eststo pA_dv_2: reg `dv2' male_pitch_mfi `full_controls', vce(robust) 
					su `dv2' if male_pitch_mfi==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pA_dv2_1: reg `dv3' male_pitch_mfi `full_controls', vce(robust) 
					su `dv3' if male_pitch_mfi==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
		qui eststo pA_dv2_2: reg `dv4' male_pitch_mfi `full_controls', vce(robust) 
					su `dv4' if male_pitch_mfi==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pA_dv3_1: reg `dv5' male_pitch_mfi `full_controls', vce(robust) 
					su `dv5' if male_pitch_mfi==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
								
		qui eststo pA_dv3_2: reg `dv6' male_pitch_mfi `full_controls', vce(robust) 
					su `dv6' if male_pitch_mfi==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace							
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
		
		qui eststo pB_dv_1: reg `dv' male_pitch_mfi male male_sector_mfi inter_malepitch_construction_mfi `full_controls', vce(robust) 
		            lincom male_pitch_mfi+inter_malepitch_construction_mfi
					loc pval_sector: di %8.3f r(p)
					su `dv' if male_pitch_mfi==0 & male_sector_mfi==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_sector', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pB_dv_2: reg `dv2' male_pitch_mfi male male_sector_mfi inter_malepitch_construction_mfi `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_construction_mfi
					loc pval_sector: di %8.3f r(p)
					su `dv2' if male_pitch_mfi==0 & male_sector_mfi==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_sector', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pB_dv2_1: reg `dv3' male_pitch_mfi male male_sector_mfi inter_malepitch_construction_mfi `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_construction_mfi
					loc pval_sector: di %8.3f r(p)
					su `dv3' if male_pitch_mfi==0 & male_sector_mfi==0, mean 
					         loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_sector', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pB_dv2_2: reg `dv4' male_pitch_mfi male male_sector_mfi inter_malepitch_construction_mfi `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_construction_mfi
					loc pval_sector: di %8.3f r(p)
					su `dv4' if male_pitch_mfi==0 & male_sector_mfi==0, mean
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_sector', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pB_dv3_1: reg `dv5' male_pitch_mfi male male_sector_mfi inter_malepitch_construction_mfi `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_construction_mfi
					loc pval_sector: di %8.3f r(p)
					su `dv5' if male_pitch_mfi==0 & male_sector_mfi==0, mean
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_sector', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace								

		qui eststo pB_dv3_2: reg `dv6' male_pitch_mfi male male_sector_mfi inter_malepitch_construction_mfi `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_construction_mfi
					loc pval_sector: di %8.3f r(p)
					su `dv6' if male_pitch_mfi==0 & male_sector_mfi==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_sector', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace			
											
		qui eststo pC_dv_1: reg `dv' male_pitch_mfi mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv' if male_pitch_mfi==0 & mod_strong_association==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pC_dv_2: reg `dv2' male_pitch_mfi mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
					lincom male_pitch_mfi+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv2' if male_pitch_mfi==0 & mod_strong_association==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pC_dv2_1: reg `dv3' male_pitch_mfi mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv3' if male_pitch_mfi==0 & mod_strong_association==0, mean 
					         loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pC_dv2_2: reg `dv4' male_pitch_mfi mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv4' if male_pitch_mfi==0 & mod_strong_association==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pC_dv3_1: reg `dv5' male_pitch_mfi mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv5' if male_pitch_mfi==0 & mod_strong_association==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace								

		qui eststo pC_dv3_2: reg `dv6' male_pitch_mfi mod_strong_association inter_malepitch_modstrongass `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_modstrongass
					loc pval_bias: di %8.3f r(p)
					su `dv6' if male_pitch_mfi==0 & mod_strong_association==0, mean  
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace			
								

		qui eststo pD_dv_1: reg `dv' male_pitch_mfi gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv' if male_pitch_mfi==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pD_dv_2: reg `dv2' male_pitch_mfi gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv2' if male_pitch_mfi==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace								
												
		qui eststo pD_dv2_1: reg `dv3' male_pitch_mfi gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv3' if male_pitch_mfi==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace	
								
		qui eststo pD_dv2_2: reg `dv4' male_pitch_mfi gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust)
				    lincom male_pitch_mfi+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv4' if male_pitch_mfi==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
							
								
		qui eststo pD_dv3_1: reg `dv5' male_pitch_mfi gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv5' if male_pitch_mfi==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace	
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "", replace								

		qui eststo pD_dv3_2: reg `dv6' male_pitch_mfi gen_att_agree inter_malepitch_genattagree `full_controls', vce(robust) 
				    lincom male_pitch_mfi+inter_malepitch_genattagree
					loc pval_bias: di %8.3f r(p)
					su `dv6' if male_pitch_mfi==0 & gen_att_agree==0, mean 
							loc mymean: di %8.2f r(mean) 	
								estadd loc mD `mymean', replace
								estadd loc pval1=`pval_bias', replace
								estadd loc statefe "$\checkmark$", replace 	
								estadd loc controls "$\checkmark$", replace	
																				
				
	loc dv_no_us = subinstr("`dv'", "_", "", . ) 
}
	
	#delimit ; 
	loc heading "MFI Sample: Pure Gender Bias and Heterogeneity by Sector and Gender Atttiudes"; 
    loc file "$DIREC_OUTPUT/chigigntobiyamfi_all_`dv'.tex"; 

	
	loc resize 1.0; 
			esttab  pA_dv_1 pA_dv_2 pA_dv2_1 pA_dv2_2 pA_dv3_1 pA_dv3_2 using "`file'", se r2 label compress replace obslast depvars nocons nomtitles nonum style(tex) fragment booktabs            cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch_mfi) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch "Male Pitch") 	 		   
			s(N mD, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch)")) 
			prehead(
				\begin{table}[!htbp] 
				\centering 
				\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
				\label{tab:LFPR`dv_no_us'}
				\caption{`heading'}  
				\subcaption*{\textbf{Investment, Entrepreneur and Business Outcomes}}
				\vspace{-0.4cm}
				\label{tab:regTabInvestment}
				\begin{adjustbox}{width=\adjregTab\textwidth}
				\begin{tabular}{@{}l*{@M}{c}}\tabularnewline \hline \noalign{\smallskip}
				&\multicolumn{1}{c}{\makecell{\text{Tycoons should} \\ {choose to invest} \\ {(Yes 1 No 0)}}}&\multicolumn{1}{c}{\makecell{\text{Investment Amount} \\ {Conditional} \\ {(ETB in thousands)}}}&\multicolumn{1}{c}{\makecell{\text{Entrepreneur} \\ {overall rating} \\ {(Score 0-10)}}}&\multicolumn{1}{c}{\makecell{\text{Entrepreneur} \\ {knowledge and skills} \\ {(Score 0-10)}}}&\multicolumn{1}{c}{\makecell{\text{Entrepreneur} \\ {Interpersonal Skills} \\ {(Index 0-3)}}}&\multicolumn{1}{c}{\makecell{\text{Business idea} \\ {risk index} \\ {(Score 0-4)}}} \\\cmidrule(l){2-3}\cmidrule(l){4-5}\cmidrule(l){6-7}\cmidrule(l){8-9}    
				& (1)  & (2) & (3) & (4) & (5) & (6) \\ \cline{2-7}
				)
				posthead(\hline \noalign{\medskip}
                \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel A (Pure Gender Bias)}} \\
				\noalign{\smallskip}
								 \\ [-3ex]
								 )
				prefoot(\hline \noalign{\smallskip}
				)
				postfoot(\noalign{\smallskip}
												  )
			;			 
	#delimit cr 
	
		*** Panel B
				
		#delimit ;
				
				esttab pB_dv_1 pB_dv_2 pB_dv2_1 pB_dv2_2 pB_dv3_1 pB_dv3_2 
					   using "`file'", append style(tex) fragment booktabs label
           cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch_mfi male_sector_mfi inter_malepitch_construction_mfi) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch_mfi "Male Pitch [A]" male_sector_mfi "Construction Sector [B]" inter_malepitch_construction_mfi "Male Pitch $\times\$ Construction Sector [C]") 	 	
			s(N mD pval1, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch)" "p-value [A]+[C]")) 
			    posthead("
						 		 \hline \\
								 \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel B (Heterogeneity by Sector)}} \\
								 \noalign{\smallskip}
								 \\ [-3ex]
								 ")	
				prefoot(\hline \noalign{\medskip}
				)
				postfoot(\noalign{\smallskip}
												  )
			;			 
	#delimit cr 	
	
		*** Panel C
				
		#delimit ;
				
				esttab pC_dv_1 pC_dv_2 pC_dv2_1 pC_dv2_2 pC_dv3_1 pC_dv3_2 
					   using "`file'", append style(tex) fragment booktabs label
           cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch_mfi mod_strong_association inter_malepitch_modstrongass) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch_mfi "Male Pitch [A]" mod_strong_association "Implicit Bias (IAT) [B]" inter_malepitch_modstrongass "Male Pitch $\times\$ Implicit Bias (IAT) [C]") 	 	
			s(N mD pval1, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch)" "p-value [A]+[C]")) 
			    posthead("
						 		 \hline \\
								 \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel C (Implicit Gender Attitudes)}} \\
								 \noalign{\smallskip}
								 \\ [-3ex]
								 ")	
				prefoot(\hline \noalign{\medskip}
				)
				postfoot(\noalign{\smallskip}
												  )
			;			 
	#delimit cr 
	
		*** Panel D
				
		#delimit ;
				
				esttab pD_dv_1 pD_dv_2 pD_dv2_1 pD_dv2_2 pD_dv3_1 pD_dv3_2
					   using "`file'", append style(tex) fragment booktabs label
           cells(b(star fmt(%9.2fc)) se(par fmt(%9.2fc)))
			mlabels(none) collabels(none) nomtitles nonumbers
		    keep(male_pitch_mfi gen_att_agree inter_malepitch_genattagree) legend star(* 0.10 ** 0.05 *** 0.01) title("`heading'") varlabels(male_pitch_mfi "Male Pitch [A]" gen_att_agree "Explicit Bias (Attitude) [B]" inter_malepitch_genattagree "Male Pitch $\times\$ Explicit Bias (Attitude) [C]") 	 		   
			s(N mD pval1, fmt(%9.0fc) labels("Obs" "Base Mean (Female Pitch No Bias)" "p-value [A]+[C]")) 
			    posthead("
						 		 \hline \\
								 \multicolumn{7}{l}{\hspace{-0.3cm}\textit{Panel D (Explicit Gender Attitudes)}} \\
								 \noalign{\smallskip}
								 \\ [-3ex]
								 ")	
				prefoot(\hline \noalign{\smallskip}
				)
				postfoot(\noalign{\smallskip}
				Controls & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark \\
				Strata FE & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark \\
				\hline\hline \noalign{\smallskip}
			   	\end{tabular}
				}
				\medskip
				\begin{minipage}{`resize'\textwidth}
				\begin{tablenotes}
				{\footnotesize
				\item \textit{Note: @starlegend} 
				\item [1] [1] MFI credit officer sample gender bias specification and split to explore heterogeneity by sector and measures of gender bias. Panel A is the pure gender bias. Panel B by a binary variable equal to 1 for the construction sector and 0 for the food services sector. Panel C by a binary variable equal to 1 if the viewer had a moderate or strong stereotypical association between Male with Career and Female with Family in their Implicit Association Test (23\% of sample). Panel D by a binary variable equal to 1 if the viewer personally strongly agrees or agrees that men make better executives than women do (38\% of sample).
				\item [2] [2] OLS regression specification with robust standard errors. Controls include respondent characteristics including gender, age, and years of schooling. Fixed effects for randomization strata include MFI branch and position of the MFI officer.
				}
                \end{tablenotes}
				\end{minipage}
				\end{adjustbox}
				\end{table}
				); 	
	#delimit cr 
			
	
*******************
*Figure A1 - Distribution Graph IAT Score
*******************	

use "$DIREC_DTA/2_finaldata/Chigign_Tobiya_IAT_TVET_MFI_Data_Clean_merged.dta", clear

gl title "`category': IAT Distribution"
gl subtitle "`gender'"
gl outcome1 IAT if female==0 & second_video==0
gl outcome2 IAT if female==1 & second_video==0
gl outcome3 IAT if female_mfi==0 & second_video==0
gl outcome4 IAT if female_mfi==1 & second_video==0

sum $outcome1 
local 	mean_1 = r(mean)
local N1 = `r(N)'

sum $outcome2  
local 	mean_2 = r(mean)
local N2 = `r(N)'

sum $outcome3  
local 	mean_3 = r(mean)
local N3 = `r(N)'

sum $outcome4 
local 	mean_4 = r(mean)
local N4 = `r(N)'


# d;
twoway 	(kdensity $outcome1, color(blue%75))
        (kdensity $outcome2, color(gold%75))
		(kdensity $outcome3, color(cranberry%75))
        (kdensity $outcome4, color(purple%75)), 
		xline(`mean_1', lcolor(blue%50) lpattern(dash)) 
		xline(`mean_2', lcolor(gold%50) lpattern(dash)) 
	    xline(`mean_3', lcolor(cranberry%50) lpattern(dash)) 
	    xline(`mean_4', lcolor(purple%50) lpattern(dash)) 
		legend(order(1 "Male TVET" 2 "Female TVET" 3 "Male MFI" 4 "Female MFI")) 
		xtitle(IAT (D-score), size(small))  xlabel(0(1.0)2,labsize (small)) 
		ytitle(Density, size(small)) ylabel(0 (0.1)1.2,labsize (vsmall))  
		bgcolor (white) graphregion(color(white))
		title("$title", justification(left) color(black) span pos(12) size(medium)) 
		subtitle("$subtitle", justification(left) color(black) span pos(12) size(small))
		note("Num TVET male IAT =`N1'"
		     "Num TVET female IAT =`N2'"
			 "Num MFI male IAT =`N3'"
			 "Num MFI female IAT =`N4'", size(small));
			
	#delimit cr 
	  graph export "$DIREC_OUTPUT/Figures\IAT.png", replace	
		
************************************************************************

*end 
